package org.globalplatform.csp.api;

public interface CSPProtocol {

    /**
     * Constant of CSPMode (1/2) (ENUMERATED):
     * The CSP can be configured by the CSP Admin.
     */
    byte CSP_MODE_CONFIGURATION = (byte) 0x00;
    /**
     * Constant of CSPMode (2/2) (ENUMERATED):
     * The CSP can be used by Client Applications.
     */
    byte CSP_MODE_OPERATIONAL = (byte) 0x01;


    /**
     * Constant of CSPErrorMode (1/2) (ENUMERATED):
     * The CSP uses only codes 1000, 2000, 3000, 4000, 5000, 6000, 7000, 8000.
     */
    byte ERROR_MODE_BASIC = (byte) 0x00;
    /**
     * Constant of CSPErrorMode (2/2) (ENUMERATED):
     * The CSP uses detailed error codes 1xxx-8xxx.
     */
    byte ERROR_MODE_DETAILED = (byte) 0x01;


    /**
     * Constant of CSPResourceState (1/5) (ENUMERATED):
     * Uninitialized state for resources.
     */
    byte STATE_UNINITIALIZED = (byte) 0x01;
    /**
     * Constant of CSPResourceState (2/5) (ENUMERATED):
     * Operational state for resources.
     */
    byte STATE_OPERATIONAL = (byte) 0x02;
    /**
     * Constant of CSPResourceState (3/5) (ENUMERATED):
     * Blocked state when the password try limit is reached.
     */
    byte STATE_BLOCKED = (byte) 0x09;
    /**
     * Constant of CSPResourceState (4/5) (ENUMERATED):
     * Exhausted state when a counter exceeds the configured limit.
     */
    byte STATE_EXHAUSTED = (byte) 0x0b;
    /**
     * Constant of CSPResourceState (5/5) (ENUMERATED):
     * Expired state when a timer expires.
     */
    byte STATE_EXPIRED = (byte) 0x0c;


    /**
     * Constant of CSPResourceType (1/5) (ENUMERATED):
     * Key resource type.
     */
    byte RESOURCE_KEY = (byte) 0x01;
    /**
     * Constant of CSPResourceType (2/5) (ENUMERATED):
     * Certificate resource type.
     */
    byte RESOURCE_CERTIFICATE = (byte) 0x02;
    /**
     * Constant of CSPResourceType (3/5) (ENUMERATED):
     * Password resource type.
     */
    byte RESOURCE_PASSWORD = (byte) 0x03;
    /**
     * Constant of CSPResourceType (4/5) (ENUMERATED):
     * Counter resource type.
     */
    byte RESOURCE_COUNTER = (byte) 0x04;
    /**
     * Constant of CSPResourceType (5/5) (ENUMERATED):
     * Timer resource type.
     */
    byte RESOURCE_TIMER = (byte) 0x05;


    /**
     * Constant of CSPUsageType (1/10) (ENUMERATED):
     * Restrict the use to cipher operations (keys).
     */
    byte USAGE_CIPHER = (byte) 0x01;
    /**
     * Constant of CSPUsageType (2/10) (ENUMERATED):
     * Restrict the use to signature operations (keys).
     */
    byte USAGE_SIGNATURE = (byte) 0x02;
    /**
     * Constant of CSPUsageType (3/10) (ENUMERATED):
     * Restrict the use to encryption transformation operations (keys).
     */
    byte USAGE_TRANSFORM = (byte) 0x03;
    /**
     * Constant of CSPUsageType (4/10) (ENUMERATED):
     * Restrict the use to secure message establishment (any).
     */
    byte USAGE_SECCHANNEL = (byte) 0x04;
    /**
     * Constant of CSPUsageType (5/10) (ENUMERATED):
     * Restrict the use to confidential data transfer (keys).
     */
    byte USAGE_CONFIDENTIAL = (byte) 0x05;
    /**
     * Constant of CSPUsageType (6/10) (ENUMERATED):
     * Restrict the use as attestation signing key (keys).
     */
    byte USAGE_ATTESTATION = (byte) 0x06;
    /**
     * Constant of CSPUsageType (7/10) (ENUMERATED):
     * Restrict the use to key derivation and key agreement (any).
     */
    byte USAGE_KEY = (byte) 0x07;
    /**
     * Constant of CSPUsageType (8/10) (ENUMERATED):
     * Restrict the use to password verification (passwords only).
     */
    byte USAGE_PASSWORD = (byte) 0x09;
    /**
     * Constant of CSPUsageType (9/10) (ENUMERATED):
     * Restrict the use as audit log message signing key (keys).
     */
    byte USAGE_AUDIT = (byte) 0x0c;
    /**
     * Constant of CSPUsageType (10/10) (ENUMERATED):
     * Restrict the use as offloading key for resource import/export (keys).
     */
    byte USAGE_OFFLOADING = (byte) 0x0d;


    /**
     * Constant of CSPPaddingAlgorithm (1/12) (ENUMERATED):
     * No padding; for use when padding is not supported by the algorithm.
     */
    byte PAD_NULL = (byte) 0x00;
    /**
     * Constant of CSPPaddingAlgorithm (2/12) (ENUMERATED):
     * No padding is applied to the data, even when the algorithm usually pads.
     */
    byte PAD_NOPAD = (byte) 0x01;
    /**
     * Constant of CSPPaddingAlgorithm (3/12) (ENUMERATED):
     * Padding based on the ISO 9797-1 MAC algo 3 with method 2 [ISO 9797-1].
     */
    byte PAD_ISO9797_1_M2_ALG3 = (byte) 0x05;
    /**
     * Constant of CSPPaddingAlgorithm (4/12) (ENUMERATED):
     * Padding based on the PKCS#1 v1.5 scheme [RFC 8017].
     */
    byte PAD_PKCS1 = (byte) 0x07;
    /**
     * Constant of CSPPaddingAlgorithm (5/12) (ENUMERATED):
     * Padding based on the PKCS#1-PSS scheme [IEEE 1363-2000].
     */
    byte PAD_PKCS1_PSS = (byte) 0x08;
    /**
     * Constant of CSPPaddingAlgorithm (6/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA256.
     */
    byte PAD_PKCS1_OAEP_SHA256 = (byte) 0x0e;
    /**
     * Constant of CSPPaddingAlgorithm (7/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA384.
     */
    byte PAD_PKCS1_OAEP_SHA384 = (byte) 0x0f;
    /**
     * Constant of CSPPaddingAlgorithm (8/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA512.
     */
    byte PAD_PKCS1_OAEP_SHA512 = (byte) 0x10;
    /**
     * Constant of CSPPaddingAlgorithm (9/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA3-256.
     */
    byte PAD_PKCS1_OAEP_SHA3_256 = (byte) 0x12;
    /**
     * Constant of CSPPaddingAlgorithm (10/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA3-384.
     */
    byte PAD_PKCS1_OAEP_SHA3_384 = (byte) 0x13;
    /**
     * Constant of CSPPaddingAlgorithm (11/12) (ENUMERATED):
     * Padding based on the PKCS#1-OAEP scheme [IEEE 1363-2000] with SHA3-512.
     */
    byte PAD_PKCS1_OAEP_SHA3_512 = (byte) 0x14;
    /**
     * Constant of CSPPaddingAlgorithm (12/12) (ENUMERATED):
     * Padding based on the PKCS#7 scheme [RFC 5652].
     */
    byte PAD_PKCS7 = (byte) 0x02;


    /**
     * Constant of CSPCipherAlgorithm (1/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] with block size 128 in CBC mode [FIPS 81].
     */
    byte CIPHER_AES_CBC = (byte) 0x01;
    /**
     * Constant of CSPCipherAlgorithm (2/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] in Cipher Feedback (CFB) mode [FIPS 81].
     */
    byte CIPHER_AES_CFB = (byte) 0x1c;
    /**
     * Constant of CSPCipherAlgorithm (3/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] in counter (CTR) mode [ISO 10116].
     */
    byte CIPHER_AES_CTR = (byte) 0xf0;
    /**
     * Constant of CSPCipherAlgorithm (4/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] Galois/Counter Mode [SP800-38D].
     */
    byte CIPHER_AES_GCM = (byte) 0xf1;
    /**
     * Constant of CSPCipherAlgorithm (5/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] in Counter with CBC-MAC mode [SP800-38C].
     */
    byte CIPHER_AES_CCM = (byte) 0xf2;
    /**
     * Constant of CSPCipherAlgorithm (6/7) (ENUMERATED):
     * Cipher using AES [FIPS 197] in XTS mode in [IEEE 1619-2018].
     */
    byte CIPHER_AES_XTS = (byte) 0x0a;
    /**
     * Constant of CSPCipherAlgorithm (7/7) (ENUMERATED):
     * Cipher using RSA [PKCS #1].
     */
    byte CIPHER_RSA = (byte) 0x07;


    /**
     * Constant of CSPMessageDigestAlgorithm (1/7) (ENUMERATED):
     * No message digest is applied to the data.
     */
    byte ALG_NULL = (byte) 0x00;
    /**
     * Constant of CSPMessageDigestAlgorithm (2/7) (ENUMERATED):
     * SHA-256 [FIPS 81] with block size of 64 and hash size of 32 bytes.
     */
    byte ALG_SHA_256 = (byte) 0x04;
    /**
     * Constant of CSPMessageDigestAlgorithm (3/7) (ENUMERATED):
     * SHA-384 [FIPS 81] with block size of 128 and hash value of 64 bytes.
     */
    byte ALG_SHA_384 = (byte) 0x05;
    /**
     * Constant of CSPMessageDigestAlgorithm (4/7) (ENUMERATED):
     * SHA-512 [FIPS 81] with block size of 128 and hash size of 64 bytes.
     */
    byte ALG_SHA_512 = (byte) 0x06;
    /**
     * Constant of CSPMessageDigestAlgorithm (5/7) (ENUMERATED):
     * SHA3-256 [FIPS 180-4] with block size of 64 and hash size of 32 bytes.
     */
    byte ALG_SHA3_256 = (byte) 0x09;
    /**
     * Constant of CSPMessageDigestAlgorithm (6/7) (ENUMERATED):
     * SHA3-384 [FIPS 180-4] with block size of 128 and hash size of 64 bytes.
     */
    byte ALG_SHA3_384 = (byte) 0x0a;
    /**
     * Constant of CSPMessageDigestAlgorithm (7/7) (ENUMERATED):
     * SHA3-512 [FIPS 180-4] with block size of 128 and hash size of 64 bytes.
     */
    byte ALG_SHA3_512 = (byte) 0x0b;


    /**
     * Constant of CSPSignatureAlgorithm (1/4) (ENUMERATED):
     * Signature according to [ISO 9797-1]: AES 128-bit block and 16-byte CMAC.
     */
    byte SIG_AES_CMAC128 = (byte) 0x0a;
    /**
     * Constant of CSPSignatureAlgorithm (2/4) (ENUMERATED):
     * Signature according to [SP800-38B]: AES 128-bit block and 16-byte MAC.
     */
    byte SIG_AES_MAC128 = (byte) 0x06;
    /**
     * Constant of CSPSignatureAlgorithm (3/4) (ENUMERATED):
     * Signature using HMAC according to [FIPS 198-1].
     */
    byte SIG_HMAC = (byte) 0x07;
    /**
     * Constant of CSPSignatureAlgorithm (4/4) (ENUMERATED):
     * RSA signature according to [IEEE 1363-2000] with PKCS#1-PSS.
     */
    byte SIG_RSA = (byte) 0x03;


    /**
     * Constant of CSPProtocolType (1/6) (ENUMERATED):
     * Password Authenticated Connection Establishment [TR-03110-3].
     */
    byte PROTOCOL_PACE = (byte) 0x11;
    /**
     * Constant of CSPProtocolType (2/6) (ENUMERATED):
     * Extended Access Control v2 (PACE, TA2, CA2, CA3) [TR-03110-3].
     */
    byte PROTOCOL_EAC_ID = (byte) 0x12;
    /**
     * Constant of CSPProtocolType (3/6) (ENUMERATED):
     * Extended Access Control v1 (PACE, CA1, TA1) [ICAO 9303-11].
     */
    byte PROTOCOL_EAC_MRTD = (byte) 0x13;
    /**
     * Constant of CSPProtocolType (4/6) (ENUMERATED):
     * PACE with Chip Authentication Mapping (PACE, CA1, TA1) [ICAO 9303-11].
     */
    byte PROTOCOL_PACE_CAM = (byte) 0x14;
    /**
     * Constant of CSPProtocolType (5/6) (ENUMERATED):
     * GP Secure Channel Protocol '03' [GP Amd D].
     */
    byte PROTOCOL_SCP03 = (byte) 0x05;
    /**
     * Constant of CSPProtocolType (6/6) (ENUMERATED):
     * GP Secure Channel Protocol '04' [GP Amd K].
     */
    byte PROTOCOL_SCP04 = (byte) 0x15;


    /**
     * Constant of CSPSecurityFunction (1/17) (ENUMERATED):
     * Password Authenticated Connection Establishment (PACE) PIN [TR-03110-2].
     */
    byte SEC_PACE_PIN = (byte) 0x01;
    /**
     * Constant of CSPSecurityFunction (2/17) (ENUMERATED):
     * Personal Unblocking Key (PUK) for PACE [TR-03110-2].
     */
    byte SEC_PACE_PUK = (byte) 0x02;
    /**
     * Constant of CSPSecurityFunction (3/17) (ENUMERATED):
     * Personal Unblocking Key (PUK) for PACE [TR-03110-1].
     */
    byte SEC_PACE_CAN = (byte) 0x03;
    /**
     * Constant of CSPSecurityFunction (4/17) (ENUMERATED):
     * Personal Unblocking Key (PUK) for PACE [TR-03110-2].
     */
    byte SEC_PACE_MRZ = (byte) 0x04;
    /**
     * Constant of CSPSecurityFunction (5/17) (ENUMERATED):
     * Authentication Terminal Root Certificate (AT-Root) for eID [TR-03110-2].
     */
    byte SEC_TA_AT_ROOT = (byte) 0x05;
    /**
     * Constant of CSPSecurityFunction (6/17) (ENUMERATED):
     * Inspection System Root Certificate (IS-Root) for MRTD [TR-03110-2].
     */
    byte SEC_TA_IS_ROOT = (byte) 0x06;
    /**
     * Constant of CSPSecurityFunction (7/17) (ENUMERATED):
     * Chip Authentication v1 (CA1) for MRTD [TR-03110-1].
     */
    byte SEC_CA1 = (byte) 0x07;
    /**
     * Constant of CSPSecurityFunction (8/17) (ENUMERATED):
     * Chip Authentication v2 (CA2) group key for eID [TR-03110-2].
     */
    byte SEC_CA2 = (byte) 0x08;
    /**
     * Constant of CSPSecurityFunction (9/17) (ENUMERATED):
     * Chip-specific CA2 key for Privileged Terminals eID [TR-03110-3].
     */
    byte SEC_CA2_PRIVILEGED = (byte) 0x09;
    /**
     * Constant of CSPSecurityFunction (10/17) (ENUMERATED):
     * Chip Authentication v3 (CA3) group key for eID [TR-03110-2].
     */
    byte SEC_CA3 = (byte) 0x0a;
    /**
     * Constant of CSPSecurityFunction (11/17) (ENUMERATED):
     * Chip-specific CA3 key for Pseudonymous Secure Authentication (PSA) eID.
     */
    byte SEC_CA3_PSA = (byte) 0x0b;
    /**
     * Constant of CSPSecurityFunction (12/17) (ENUMERATED):
     * Output: Document Verify certificate received during EAC [TR-03110-3].
     */
    byte SEC_TA_DV = (byte) 0x0c;
    /**
     * Constant of CSPSecurityFunction (13/17) (ENUMERATED):
     * Output: Certificate received from individual terminals [TR-03110-3].
     */
    byte SEC_TA_TERMINAL = (byte) 0x0d;
    /**
     * Constant of CSPSecurityFunction (14/17) (ENUMERATED):
     * Output: Linked TA certificate for rollover in eID [TR-03110-3].
     */
    byte SEC_TA_AT_LINKED = (byte) 0x0e;
    /**
     * Constant of CSPSecurityFunction (15/17) (ENUMERATED):
     * Output: Linked TA certificate for rollover in MRTD [TR-03110-3].
     */
    byte SEC_TA_IS_LINKED = (byte) 0x0f;
    /**
     * Constant of CSPSecurityFunction (16/17) (ENUMERATED):
     * Encryption Key for SCP03 [GP Amd D] and SCP04 [GP Amd K].
     */
    byte SEC_KENC = (byte) 0x20;
    /**
     * Constant of CSPSecurityFunction (17/17) (ENUMERATED):
     * MAC Key for SCP03 [GP Amd D] and SCP04 [GP Amd K].
     */
    byte SEC_KMAC = (byte) 0x21;


    /**
     * Constant of CSPSystemAttestationType (1/2) (ENUMERATED):
     * Attestation of the SE Platform the CSP is operated on.
     */
    byte ATTESTATION_PLATFORM = (byte) 0x01;
    /**
     * Constant of CSPSystemAttestationType (2/2) (ENUMERATED):
     * Attestation of the configuration of this CSP Instance.
     */
    byte ATTESTATION_CONFIG = (byte) 0x02;


    /**
     * Constant of CSPResourceAttestationType (1/3) (ENUMERATED):
     * Attestation of external data with public key, counter or timer.
     */
    byte ATTESTATION_DATA = (byte) 0x03;
    /**
     * Constant of CSPResourceAttestationType (2/3) (ENUMERATED):
     * Attestation of public key with proof of possession for the private key.
     */
    byte ATTESTATION_KEY_POP = (byte) 0x04;
    /**
     * Constant of CSPResourceAttestationType (3/3) (ENUMERATED):
     * Generate a new key pair and returns a PoP attestation.
     */
    byte ATTESTATION_KEY_GENERATION = (byte) 0x05;


    /**
     * Constant of CSPKeyType (1/9) (ENUMERATED):
     * Symmetric key used with Advanced Encryption Standard (AES).
     */
    byte KEY_AES = (byte) 0x01;
    /**
     * Constant of CSPKeyType (2/9) (ENUMERATED):
     * Symmetric key used to create HMAC-based signatures.
     */
    byte KEY_HMAC = (byte) 0x02;
    /**
     * Constant of CSPKeyType (3/9) (ENUMERATED):
     * Public key used for Elliptic Curve Cryptography (ECC).
     */
    byte KEY_ECC_PUBLIC = (byte) 0x03;
    /**
     * Constant of CSPKeyType (4/9) (ENUMERATED):
     * Private key used for Elliptic Curve Cryptography (ECC).
     */
    byte KEY_ECC_PRIVATE = (byte) 0x04;
    /**
     * Constant of CSPKeyType (5/9) (ENUMERATED):
     * Public key for Rivest-Shamir-Adleman (RSA) algorithms.
     */
    byte KEY_RSA_PUBLIC = (byte) 0x05;
    /**
     * Constant of CSPKeyType (6/9) (ENUMERATED):
     * Private key for Rivest-Shamir-Adleman (RSA) algorithms.
     */
    byte KEY_RSA_PRIVATE = (byte) 0x06;
    /**
     * Constant of CSPKeyType (7/9) (ENUMERATED):
     * Secret generated within the CSP, used for key derivation.
     */
    byte MASTER_SECRET = (byte) 0x07;
    /**
     * Constant of CSPKeyType (8/9) (ENUMERATED):
     * Secret result from key derivation, used for further key derivation.
     */
    byte DERIVED_SECRET = (byte) 0x08;
    /**
     * Constant of CSPKeyType (9/9) (ENUMERATED):
     * Secret from key agreement, used for key derivation.
     */
    byte KEY_SHARED_SECRET = (byte) 0x09;


    /**
     * Constant of CSPKeySize (1/19) (ENUMERATED):
     * KEY_AES 128 bit.
     */
    byte KEY_AES_128 = (byte) 0x01;
    /**
     * Constant of CSPKeySize (2/19) (ENUMERATED):
     * KEY_AES 256 bit.
     */
    byte KEY_AES_256 = (byte) 0x03;
    /**
     * Constant of CSPKeySize (3/19) (ENUMERATED):
     * KEY_AES 2x128 bit for CIPHER_AES_XTS.
     */
    byte KEY_AES_2_128 = (byte) 0x05;
    /**
     * Constant of CSPKeySize (4/19) (ENUMERATED):
     * KEY_AES 2x256 bit for CIPHER_AES_XTS.
     */
    byte KEY_AES_2_256 = (byte) 0x07;
    /**
     * Constant of CSPKeySize (5/19) (ENUMERATED):
     * KEY_HMAC 256 bit.
     */
    byte KEY_HMAC_256 = (byte) 0x0a;
    /**
     * Constant of CSPKeySize (6/19) (ENUMERATED):
     * KEY_HMAC 384 bit.
     */
    byte KEY_HMAC_384 = (byte) 0x0b;
    /**
     * Constant of CSPKeySize (7/19) (ENUMERATED):
     * KEY_HMAC 512 bit.
     */
    byte KEY_HMAC_512 = (byte) 0x0c;
    /**
     * Constant of CSPKeySize (8/19) (ENUMERATED):
     * KEY_ECC_PUBLIC and KEY_ECC_PRIVATE 256 bit.
     */
    byte KEY_ECC_256 = (byte) 0x10;
    /**
     * Constant of CSPKeySize (9/19) (ENUMERATED):
     * KEY_ECC_PUBLIC and KEY_ECC_PRIVATE 384 bit.
     */
    byte KEY_ECC_384 = (byte) 0x11;
    /**
     * Constant of CSPKeySize (10/19) (ENUMERATED):
     * KEY_ECC_PUBLIC and KEY_ECC_PRIVATE 512 bit.
     */
    byte KEY_ECC_512 = (byte) 0x12;
    /**
     * Constant of CSPKeySize (11/19) (ENUMERATED):
     * KEY_ECC_PUBLIC and KEY_ECC_PRIVATE 521 bit.
     */
    byte KEY_ECC_521 = (byte) 0x13;
    /**
     * Constant of CSPKeySize (12/19) (ENUMERATED):
     * KEY_RSA_PUBLIC and KEY_RSA_PRIVATE 2048 bit.
     */
    byte KEY_RSA_2048 = (byte) 0x1a;
    /**
     * Constant of CSPKeySize (13/19) (ENUMERATED):
     * KEY_RSA_PUBLIC and KEY_RSA_PRIVATE 3072 bit.
     */
    byte KEY_RSA_3072 = (byte) 0x1b;
    /**
     * Constant of CSPKeySize (14/19) (ENUMERATED):
     * KEY_RSA_* 4096 bit; do not generate, only for import recommended.
     */
    byte KEY_RSA_4096 = (byte) 0x1c;
    /**
     * Constant of CSPKeySize (15/19) (ENUMERATED):
     * KEY_MASTER_SECRET, KEY_DERIVED_SECRET and KEY_SHARED_SECRET 128 bit.
     */
    byte KEY_SECRET_128 = (byte) 0x20;
    /**
     * Constant of CSPKeySize (16/19) (ENUMERATED):
     * KEY_MASTER_SECRET, KEY_DERIVED_SECRET and KEY_SHARED_SECRET 256 bit.
     */
    byte KEY_SECRET_256 = (byte) 0x21;
    /**
     * Constant of CSPKeySize (17/19) (ENUMERATED):
     * KEY_MASTER_SECRET, KEY_DERIVED_SECRET and KEY_SHARED_SECRET 384 bit.
     */
    byte KEY_SECRET_384 = (byte) 0x22;
    /**
     * Constant of CSPKeySize (18/19) (ENUMERATED):
     * KEY_MASTER_SECRET, KEY_DERIVED_SECRET and KEY_SHARED_SECRET 512 bit.
     */
    byte KEY_SECRET_512 = (byte) 0x23;
    /**
     * Constant of CSPKeySize (19/19) (ENUMERATED):
     * KEY_MASTER_SECRET and KEY_DERIVED_SECRET.
     */
    byte KEY_SECRET_576 = (byte) 0x24;


    /**
     * Constant of CSPCurve (1/7) (ENUMERATED):
     * Brainpool P256 r1 [RFC 5639].
     */
    byte CURVE_BRAINPOOL_P256_R1 = (byte) 0x01;
    /**
     * Constant of CSPCurve (2/7) (ENUMERATED):
     * Brainpool P384 r1 [RFC 5639].
     */
    byte CURVE_BRAINPOOL_P384_R1 = (byte) 0x02;
    /**
     * Constant of CSPCurve (3/7) (ENUMERATED):
     * Brainpool P512 r1 [RFC 5639].
     */
    byte CURVE_BRAINPOOL_P512_R1 = (byte) 0x03;
    /**
     * Constant of CSPCurve (4/7) (ENUMERATED):
     * NIST's P-256 curve [SP800-186].
     */
    byte CURVE_SEC_P256_R1 = (byte) 0x04;
    /**
     * Constant of CSPCurve (5/7) (ENUMERATED):
     * NIST's P-384 curve [SP800-186].
     */
    byte CURVE_SEC_P384_R1 = (byte) 0x05;
    /**
     * Constant of CSPCurve (6/7) (ENUMERATED):
     * NIST's P-521 curve [SP800-186].
     */
    byte CURVE_SEC_P521_R1 = (byte) 0x06;
    /**
     * Constant of CSPCurve (7/7) (ENUMERATED):
     * 256-bit, only key agreement [RFC 7748].
     */
    byte CURVE_X25519 = (byte) 0x07;


    /**
     * Constant of CSPKeyDerivationAlgorithm (1/4) (ENUMERATED):
     * Two-step key derivation [SP800-56C].
     */
    byte KDF_AES_CMAC = (byte) 0x01;
    /**
     * Constant of CSPKeyDerivationAlgorithm (2/4) (ENUMERATED):
     * ECC private key derivation from a secret [TR-03111].
     */
    byte KDF_ECC = (byte) 0x02;
    /**
     * Constant of CSPKeyDerivationAlgorithm (3/4) (ENUMERATED):
     * HMAC-based key derivation [RFC 5869].
     */
    byte KDF_HKDF = (byte) 0x03;
    /**
     * Constant of CSPKeyDerivationAlgorithm (4/4) (ENUMERATED):
     * Password-based key derivation [PKCS #5].
     */
    byte KDF_PBKDF2 = (byte) 0x04;


    /**
     * Constant of CSPKeyAgreementScheme (1/2) (ENUMERATED):
     * ECC Diffie-Hellman key agreement.
     */
    byte KAS_ECKA_DH = (byte) 0x01;
    /**
     * Constant of CSPKeyAgreementScheme (2/2) (ENUMERATED):
     * ECC ElGamal key agreement.
     */
    byte KAS_ECKA_EG = (byte) 0x02;


    /**
     * Constant of CSPCertificateType (1/2) (ENUMERATED):
     * Card Verifiable Certificate (CVC) according to [TR-03110-3].
     */
    byte CERT_CVC = (byte) 0x01;
    /**
     * Constant of CSPCertificateType (2/2) (ENUMERATED):
     * X.509 Certificate according to [ITU-T X.509].
     */
    byte CERT_X509 = (byte) 0x02;


    /**
     * Constant of CSPPasswordType (1/5) (ENUMERATED):
     * No rules apply on passwords.
     */
    byte PWD_ANY = (byte) 0x00;
    /**
     * Constant of CSPPasswordType (2/5) (ENUMERATED):
     * Only ASCII numbers (e.g., PIN or PUK).
     */
    byte PWD_NUMERIC = (byte) 0x01;
    /**
     * Constant of CSPPasswordType (3/5) (ENUMERATED):
     * ASCII alphanumeric (0-9, a-z, A-Z).
     */
    byte PWD_ALPHANUMERIC = (byte) 0x02;
    /**
     * Constant of CSPPasswordType (4/5) (ENUMERATED):
     * UTF-8 charset.
     */
    byte PWD_UTF8 = (byte) 0x03;
    /**
     * Constant of CSPPasswordType (5/5) (ENUMERATED):
     * UTF-8 charset, min. 1 uppercase, 1 lowercase, 1 number, 1 special.
     */
    byte PWD_STRONG = (byte) 0x04;


    /**
     * Constant of CSPCounterMode (1/3) (ENUMERATED):
     * Counter functionality is disabled or not available.
     */
    byte COUNTER_MODE_OFF = (byte) 0x00;
    /**
     * Constant of CSPCounterMode (2/3) (ENUMERATED):
     * Ignore counters configured if not supported by the platform.
     */
    byte COUNTER_MODE_IGNORE = (byte) 0x01;
    /**
     * Constant of CSPCounterMode (3/3) (ENUMERATED):
     * Stop operation if a configured counter is not supported.
     */
    byte COUNTER_MODE_STRICT = (byte) 0x02;


    /**
     * Constant of CSPCounterType (1/7) (ENUMERATED):
     * Manual counter invoked by the Client Application.
     */
    byte COUNT_MANUAL = (byte) 0x01;
    /**
     * Constant of CSPCounterType (2/7) (ENUMERATED):
     * usage counter counting each computation, including each cipher block.
     */
    byte COUNT_USAGE_PER_BLOCK = (byte) 0x02;
    /**
     * Constant of CSPCounterType (3/7) (ENUMERATED):
     * usage counter counting complete processes (e.g., only doFinal calls).
     */
    byte COUNT_USAGE_COMPLETIONS = (byte) 0x03;
    /**
     * Constant of CSPCounterType (4/7) (ENUMERATED):
     * Usage counter counting only successful processes (excluding updates).
     */
    byte COUNT_USAGE_SUCCESS_ONLY = (byte) 0x04;
    /**
     * Constant of CSPCounterType (5/7) (ENUMERATED):
     * Usage counter counting only failed processes (excluding updates).
     */
    byte COUNT_USAGE_FAILURE_ONLY = (byte) 0x05;
    /**
     * Constant of CSPCounterType (6/7) (ENUMERATED):
     * Password authentication timeout realized as usage counter.
     */
    byte COUNT_AUTH_USAGE = (byte) 0x06;
    /**
     * Constant of CSPCounterType (7/7) (ENUMERATED):
     * Transport counter (e.g., OTP) for passwords in transport.
     */
    byte COUNT_TRANSPORT_USAGE = (byte) 0x07;


    /**
     * Constant of CSPCounterCapacity (1/4) (ENUMERATED):
     * Tiny: 1-byte counter supporting 10,000 increments.
     */
    byte COUNTER_TINY = (byte) 0x01;
    /**
     * Constant of CSPCounterCapacity (2/4) (ENUMERATED):
     * Small: 2-byte counter supporting 10,000 increments.
     */
    byte COUNTER_SMALL = (byte) 0x02;
    /**
     * Constant of CSPCounterCapacity (3/4) (ENUMERATED):
     * Medium: 4-byte counter supporting 100,000 increments.
     */
    byte COUNTER_MEDIUM = (byte) 0x03;
    /**
     * Constant of CSPCounterCapacity (4/4) (ENUMERATED):
     * Large: 4-byte counter supporting 5,000,000 increments.
     */
    byte COUNTER_LARGE = (byte) 0x04;


    /**
     * Constant of CSPTimeMode (1/3) (ENUMERATED):
     * Time functionality is disabled or not available.
     */
    byte TIME_MODE_OFF = (byte) 0x00;
    /**
     * Constant of CSPTimeMode (2/3) (ENUMERATED):
     * Ignore time-related configurations if time is not supported.
     */
    byte TIME_MODE_IGNORE = (byte) 0x01;
    /**
     * Constant of CSPTimeMode (3/3) (ENUMERATED):
     * Stop operation if time is not synchronized.
     */
    byte TIME_MODE_STRICT = (byte) 0x02;


    /**
     * Constant of CSPTimerType (1/7) (ENUMERATED):
     * Manual timer invoked by the Client Application.
     */
    byte TIMER_MANUAL_DATE = (byte) 0x01;
    /**
     * Constant of CSPTimerType (2/7) (ENUMERATED):
     * Manual timer invoked by the Client Application.
     */
    byte TIMER_MANUAL_PERIOD = (byte) 0x02;
    /**
     * Constant of CSPTimerType (3/7) (ENUMERATED):
     * Validity period used to compute (and refresh) the validity date.
     */
    byte TIMER_VALIDITY_PERIOD = (byte) 0x03;
    /**
     * Constant of CSPTimerType (4/7) (ENUMERATED):
     * Validity date as specific Unix timestamp.
     */
    byte TIMER_VALIDITY_DATE = (byte) 0x04;
    /**
     * Constant of CSPTimerType (5/7) (ENUMERATED):
     * Validity date extracted from certificates.
     */
    byte TIMER_VALIDITY_CERTIFICATE = (byte) 0x05;
    /**
     * Constant of CSPTimerType (6/7) (ENUMERATED):
     * Timeout for authenticated passwords.
     */
    byte TIMER_AUTH_TIMEOUT = (byte) 0x06;
    /**
     * Constant of CSPTimerType (7/7) (ENUMERATED):
     * Timeout for secure channel service.
     */
    byte TIMER_SECURITY_TIMEOUT = (byte) 0x07;


    /**
     * Constant of CSPTimeoutType (1/3) (ENUMERATED):
     * Timeout functionality is disabled and/or not available.
     */
    byte TIMEOUT_OFF = (byte) 0x00;
    /**
     * Constant of CSPTimeoutType (2/3) (ENUMERATED):
     * Fixed timeout after which the authenticated state is invalidated.
     */
    byte TIMEOUT_HARD = (byte) 0x01;
    /**
     * Constant of CSPTimeoutType (3/3) (ENUMERATED):
     * Dynamic timeout that is refreshed when using the resource.
     */
    byte TIMEOUT_SOFT = (byte) 0x02;


    /**
     * Constant of CSPAuditMode (1/3) (ENUMERATED):
     * Audit event logging is disabled or not available.
     */
    byte AUDIT_MODE_OFF = (byte) 0x00;
    /**
     * Constant of CSPAuditMode (2/3) (ENUMERATED):
     * events that are not fetched will be overwritte if audit queue is full.
     */
    byte AUDIT_MODE_OVERWRITE = (byte) 0x01;
    /**
     * Constant of CSPAuditMode (3/3) (ENUMERATED):
     * CSP will throw an exception if audit event queue is full.
     */
    byte AUDIT_MODE_STRICT = (byte) 0x02;


    /**
     * Constant of CSPSystemEvent (1/6) (ENUMERATED):
     * Startup of the CSP (0x0001).
     */
    byte EVENT_CSP_START = (byte) 0x01;
    /**
     * Constant of CSPSystemEvent (2/6) (ENUMERATED):
     * Start of a CSP software update (0x0002).
     */
    byte EVENT_CSP_UPDATE_STARTED = (byte) 0x02;
    /**
     * Constant of CSPSystemEvent (3/6) (ENUMERATED):
     * CSP software update is finished (0x0003).
     */
    byte EVENT_CSP_UPDATE_FINISHED = (byte) 0x03;
    /**
     * Constant of CSPSystemEvent (4/6) (ENUMERATED):
     * The CSP configuration is modified (0x0004).
     */
    byte EVENT_CSP_CONFIG_UPDATED = (byte) 0x04;
    /**
     * Constant of CSPSystemEvent (5/6) (ENUMERATED):
     * An error occurred that was not yet covered by another event (0x0005).
     */
    byte EVENT_CSP_ERROR = (byte) 0x05;
    /**
     * Constant of CSPSystemEvent (6/6) (ENUMERATED):
     * A new reference time is set (0x00B0).
     */
    byte EVENT_CSP_TIME_SET = (byte) 0xb0;


    /**
     * Constant of CSPResourceEvent (1/25) (ENUMERATED):
     * Resource cleared successfully (0x1000).
     */
    short EVENT_RESOURCE_CLEARED = (short) 0x1000;
    /**
     * Constant of CSPResourceEvent (2/25) (ENUMERATED):
     * Resource modified (0x1001).
     */
    short EVENT_RESOURCE_VALUE_SET = (short) 0x1001;
    /**
     * Constant of CSPResourceEvent (3/25) (ENUMERATED):
     * Data encrypted successfully (0x1010).
     */
    short EVENT_CIPHER_ENCRYPTED = (short) 0x1010;
    /**
     * Constant of CSPResourceEvent (4/25) (ENUMERATED):
     * Data decrypted successfully (0x1011).
     */
    short EVENT_CIPHER_DECRYPTED = (short) 0x1011;
    /**
     * Constant of CSPResourceEvent (5/25) (ENUMERATED):
     * Signature created successfully (0x1020).
     */
    short EVENT_SIGNATURE_CREATED = (short) 0x1020;
    /**
     * Constant of CSPResourceEvent (6/25) (ENUMERATED):
     * Signature verified successfully (0x1021).
     */
    short EVENT_SIGNATURE_VERIFIED = (short) 0x1021;
    /**
     * Constant of CSPResourceEvent (7/25) (ENUMERATED):
     * Signature verification failed (0x1022).
     */
    short EVENT_SIGNATURE_VERIFICATION_FAILED = (short) 0x1022;
    /**
     * Constant of CSPResourceEvent (8/25) (ENUMERATED):
     * Secure messaging successfully established (0x1040).
     */
    short EVENT_SECURE_CHANNEL_ESTABLISHED = (short) 0x1040;
    /**
     * Constant of CSPResourceEvent (9/25) (ENUMERATED):
     * Authentication for secure messaging failed (0x1041).
     */
    short EVENT_SECURE_CHANNEL_AUTHENTICATION_FAILED = (short) 0x1041;
    /**
     * Constant of CSPResourceEvent (10/25) (ENUMERATED):
     * Key successfully generated (0x1070).
     */
    short EVENT_KEY_GENERATED = (short) 0x1070;
    /**
     * Constant of CSPResourceEvent (11/25) (ENUMERATED):
     * Key derived successfully (0x1071).
     */
    short EVENT_KEY_DERIVED = (short) 0x1071;
    /**
     * Constant of CSPResourceEvent (12/25) (ENUMERATED):
     * Successful key agreement (0x1072).
     */
    short EVENT_KEY_SHARED_SECRET_COMPUTED = (short) 0x1072;
    /**
     * Constant of CSPResourceEvent (13/25) (ENUMERATED):
     * Successfully imported a new public key value (0x1073).
     */
    short EVENT_PUBLIC_KEY_IMPORTED = (short) 0x1073;
    /**
     * Constant of CSPResourceEvent (14/25) (ENUMERATED):
     * Successfully imported a new certificate (0x1080).
     */
    short EVENT_CERTIFICATE_IMPORTED = (short) 0x1080;
    /**
     * Constant of CSPResourceEvent (15/25) (ENUMERATED):
     * Successfully exported a certificate (0x1081).
     */
    short EVENT_CERTIFICATE_EXPORTED = (short) 0x1081;
    /**
     * Constant of CSPResourceEvent (16/25) (ENUMERATED):
     * Password changed successfully (0x1090).
     */
    short EVENT_PASSWORD_UPDATED = (short) 0x1090;
    /**
     * Constant of CSPResourceEvent (17/25) (ENUMERATED):
     * Changing a password failed (0x1091).
     */
    short EVENT_PASSWORD_UPDATE_FAILED = (short) 0x1091;
    /**
     * Constant of CSPResourceEvent (18/25) (ENUMERATED):
     * Password verified successfully (0x1092).
     */
    short EVENT_PASSWORD_AUTHENTICATED = (short) 0x1092;
    /**
     * Constant of CSPResourceEvent (19/25) (ENUMERATED):
     * Password mismatch (0x1093).
     */
    short EVENT_PASSWORD_CHECK_FAILED = (short) 0x1093;
    /**
     * Constant of CSPResourceEvent (20/25) (ENUMERATED):
     * Password is blocked due to too many incorrect password attempts (0x1094)
     */
    short EVENT_PASSWORD_BLOCKED = (short) 0x1094;
    /**
     * Constant of CSPResourceEvent (21/25) (ENUMERATED):
     * A blocked password was unblocked (0x1095).
     */
    short EVENT_PASSWORD_UNBLOCKED = (short) 0x1095;
    /**
     * Constant of CSPResourceEvent (22/25) (ENUMERATED):
     * Resource counter exhausted (0x10B0).
     */
    short EVENT_COUNTER_EXHAUSTED = (short) 0x10a0;
    /**
     * Constant of CSPResourceEvent (23/25) (ENUMERATED):
     * Resource validity date expired (0x10C0).
     */
    short EVENT_TIMER_EXPIRED = (short) 0x10b0;
    /**
     * Constant of CSPResourceEvent (24/25) (ENUMERATED):
     * Resource imported for offloading (0x10D0).
     */
    short EVENT_OFFLOAD_IMPORTED = (short) 0x10d0;
    /**
     * Constant of CSPResourceEvent (25/25) (ENUMERATED):
     * Resource exported for offloading (0x10D1).
     */
    short EVENT_OFFLOAD_EXPORTED = (short) 0x10d1;


    /**
     * Constant of CSPFieldMode (1/3) (ENUMERATED):
     * Fields are disabled or not available.
     */
    byte FIELD_MODE_OFF = (byte) 0x00;
    /**
     * Constant of CSPFieldMode (2/3) (ENUMERATED):
     * Ignore field configurations that are not supported by the platform.
     */
    byte FIELD_MODE_IGNORE = (byte) 0x01;
    /**
     * Constant of CSPFieldMode (3/3) (ENUMERATED):
     * Stop operation if a field configured is not supported.
     */
    byte FIELD_MODE_STRICT = (byte) 0x02;


    /**
     * Constant of CSPFieldType (1/13) (ENUMERATED):
     * Estimated system time as Unix timestamp in seconds, 8 bytes.
     */
    byte FIELD_SYSTEM_TIME = (byte) 0x01;
    /**
     * Constant of CSPFieldType (2/13) (ENUMERATED):
     * The time since boot in seconds, 4 bytes.
     */
    byte FIELD_TIME_SINCE_BOOT = (byte) 0x02;
    /**
     * Constant of CSPFieldType (3/13) (ENUMERATED):
     * The reference time set by CSP Admin or CSP Client.
     */
    byte FIELD_REFERENCE_TIME = (byte) 0x03;
    /**
     * Constant of CSPFieldType (4/13) (ENUMERATED):
     * The The value of a resource usage counter.
     */
    byte FIELD_USAGE_COUNTER = (byte) 0x04;
    /**
     * Constant of CSPFieldType (5/13) (ENUMERATED):
     * The version of the CSP Configuration set by the CSP Admin.
     */
    byte FIELD_CSP_CONFIG_VERSION = (byte) 0x05;
    /**
     * Constant of CSPFieldType (6/13) (ENUMERATED):
     * The version of the CSP Protocol of the platform.
     */
    byte FIELD_CSP_PROTOCOL_VERSION = (byte) 0x06;
    /**
     * Constant of CSPFieldType (7/13) (ENUMERATED):
     * The version of the CSP ELF.
     */
    byte FIELD_CSP_ELF_VERSION = (byte) 0x07;
    /**
     * Constant of CSPFieldType (8/13) (ENUMERATED):
     * The resource state.
     */
    byte FIELD_RESOURCE_STATE = (byte) 0x08;
    /**
     * Constant of CSPFieldType (9/13) (ENUMERATED):
     * The value of a public key.
     */
    byte FIELD_PUBKEY = (byte) 0x09;
    /**
     * Constant of CSPFieldType (10/13) (ENUMERATED):
     * The value of a manual counter.
     */
    byte FIELD_MANUAL_COUNTER = (byte) 0x0a;
    /**
     * Constant of CSPFieldType (11/13) (ENUMERATED):
     * The limit set to a manual counter.
     */
    byte FIELD_MANUAL_COUNTER_LIMIT = (byte) 0x0b;
    /**
     * Constant of CSPFieldType (12/13) (ENUMERATED):
     * The value of a manual timer.
     */
    byte FIELD_MANUAL_TIMER = (byte) 0x0c;
    /**
     * Constant of CSPFieldType (13/13) (ENUMERATED):
     * The limit of a manual timer.
     */
    byte FIELD_MANUAL_TIMER_LIMIT = (byte) 0x0d;


    /**
     * Constant of CSPFieldSource (1/2) (ENUMERATED):
     * System data or if a resource is required the signing key resource.
     */
    byte DEFAULT_SOURCE = (byte) 0x00;
    /**
     * Constant of CSPFieldSource (2/2) (ENUMERATED):
     * The resource that triggered the audit event.
     */
    byte EVENT_SOURCE = (byte) 0x01;


    /**
     * Constant of CSPPolicyMode (1/3) (ENUMERATED):
     * Policy evaluation is disabled or not available.
     */
    byte POLICY_MODE_OFF = (byte) 0x00;
    /**
     * Constant of CSPPolicyMode (2/3) (ENUMERATED):
     * Ignore policy configurations that are not supported by the platform.
     */
    byte POLICY_MODE_IGNORE_UNSUPPORTED = (byte) 0x01;
    /**
     * Constant of CSPPolicyMode (3/3) (ENUMERATED):
     * Stop operation if a configured policy is not supported.
     */
    byte POLICY_MODE_STRICT = (byte) 0x02;


    /**
     * Constant of CSPPolicyType (1/7) (ENUMERATED):
     * The public key provided must be associated to the private key.
     */
    byte POLICY_KEYPAIR = (byte) 0x01;
    /**
     * Constant of CSPPolicyType (2/7) (ENUMERATED):
     * An associated secure channel must be fully established.
     */
    byte POLICY_SECCHANNEL_ESTABLISHED = (byte) 0x02;
    /**
     * Constant of CSPPolicyType (3/7) (ENUMERATED):
     * An associated password must be authenticated.
     */
    byte POLICY_PASSWORD = (byte) 0x03;
    /**
     * Constant of CSPPolicyType (4/7) (ENUMERATED):
     * The PUK used to unblock a password must be associated to the password.
     */
    byte POLICY_UNBLOCK_PASSWORD = (byte) 0x04;
    /**
     * Constant of CSPPolicyType (5/7) (ENUMERATED):
     * A password with tryCounter=1 requires an associated CAN authenticated.
     */
    byte POLICY_PRE_BLOCKED = (byte) 0x05;
    /**
     * Constant of CSPPolicyType (6/7) (ENUMERATED):
     * A specific access flag must be present in sec channel TA2 certificates.
     */
    byte POLICY_TA2_ACCESS_FLAG = (byte) 0x06;
    /**
     * Constant of CSPPolicyType (7/7) (ENUMERATED):
     * The second resource involved must be associated to the main resource.
     */
    byte POLICY_ASSOCIATION = (byte) 0x07;

    /**
     * Param-Tag for CSPAdminCommand (1/1):
     * 'adminCommandChoice': 
     */
    byte TAG_ADMIN_ADMIN_COMMAND_CHOICE = (byte) 0xA0;

    /**
     * Param-Tag for CSPEnforce (1/17):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_ENFORCE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPEnforce (2/17):
     * 'coreSupport': Optional core functionality (e.g., policies). (OPTIONAL)
     */
    byte TAG_ENFORCE_CORE_SUPPORT = (byte) 0xA1;
    /**
     * Param-Tag for CSPEnforce (3/17):
     * 'cipherSupport': Cipher and padding algorithms. (OPTIONAL)
     */
    byte TAG_ENFORCE_CIPHER_SUPPORT = (byte) 0xA2;
    /**
     * Param-Tag for CSPEnforce (4/17):
     * 'signatureSupport': Signature algorithms. (OPTIONAL)
     */
    byte TAG_ENFORCE_SIGNATURE_SUPPORT = (byte) 0xA3;
    /**
     * Param-Tag for CSPEnforce (5/17):
     * 'transformSupport': Cipher encryption transformation. (OPTIONAL)
     */
    byte TAG_ENFORCE_N_U_L_L = (byte) 0x84;
    /**
     * Param-Tag for CSPEnforce (6/17):
     * 'secChannelSupport': Secure channel protocols. (OPTIONAL)
     */
    byte TAG_ENFORCE_SECURE_CHANNEL_SUPPORT = (byte) 0xA5;
    /**
     * Param-Tag for CSPEnforce (7/17):
     * 'confidentialSupport': Confidential data transfer extension of the secure channel service. (OPTIONAL)
     */
    byte TAG_ENFORCE_N_U_L_L_B = (byte) 0x86;
    /**
     * Param-Tag for CSPEnforce (8/17):
     * 'attestationSupport': Attestation types. (OPTIONAL)
     */
    byte TAG_ENFORCE_ATTESTATION_SUPPORT = (byte) 0xA7;
    /**
     * Param-Tag for CSPEnforce (9/17):
     * 'keySupport': Key type, size, curve, along with derivation and agreement algorithms. (OPTIONAL)
     */
    byte TAG_ENFORCE_KEY_SUPPORT = (byte) 0xA8;
    /**
     * Param-Tag for CSPEnforce (10/17):
     * 'certificateSupport': Certificate types. (OPTIONAL)
     */
    byte TAG_ENFORCE_CERTIFICATE_SUPPORT = (byte) 0xA9;
    /**
     * Param-Tag for CSPEnforce (11/17):
     * 'passwordSupport': Password management operations. (OPTIONAL)
     */
    byte TAG_ENFORCE_PASSWORD_SUPPORT = (byte) 0xAA;
    /**
     * Param-Tag for CSPEnforce (12/17):
     * 'counterSupport': Counter types. (OPTIONAL)
     */
    byte TAG_ENFORCE_COUNTER_SUPPORT = (byte) 0xAB;
    /**
     * Param-Tag for CSPEnforce (13/17):
     * 'timeSupport': Time management and timer types. (OPTIONAL)
     */
    byte TAG_ENFORCE_TIME_SUPPORT = (byte) 0xAC;
    /**
     * Param-Tag for CSPEnforce (14/17):
     * 'auditSupport': Secure auditing and event types. (OPTIONAL)
     */
    byte TAG_ENFORCE_AUDIT_SUPPORT = (byte) 0xAD;
    /**
     * Param-Tag for CSPEnforce (15/17):
     * 'offloadingSupport': Resource import and export functionality. (OPTIONAL)
     */
    byte TAG_ENFORCE_N_U_L_L_C = (byte) 0x8E;
    /**
     * Param-Tag for CSPEnforce (16/17):
     * 'fieldSupport': Fields to be included in attestation results and log messages. (OPTIONAL)
     */
    byte TAG_ENFORCE_FIELD_SUPPORT = (byte) 0xAF;
    /**
     * Param-Tag for CSPEnforce (17/17):
     * 'policySupport': Constraint-based access control using policies. (OPTIONAL)
     */
    byte TAG_ENFORCE_POLICY_SUPPORT = (byte) 0xB0;

    /**
     * Param-Tag for CSPRegisterClient (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_REGISTER_CLIENT_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPRegisterClient (2/2):
     * 'client': The Client Application or off-card Client to register.
     */
    byte TAG_REGISTER_CLIENT_CLIENT = (byte) 0xA1;

    /**
     * Param-Tag for CSPUnregisterClient (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_UNREGISTER_CLIENT_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPUnregisterClient (2/2):
     * 'client': The client identifier or the AID of a Client Application.
     */
    byte TAG_UNREGISTER_CLIENT_CLIENT_REFERENCE = (byte) 0xA1;

    /**
     * Param-Tag for CSPCreateResource (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_CREATE_RESOURCE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPCreateResource (2/2):
     * 'resouceData': The resource data (e.g., resource ID, resource type, etc.).
     */
    byte TAG_CREATE_RESOURCE_RESOURCE = (byte) 0xA1;

    /**
     * Param-Tag for CSPDestroyResource (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_DESTROY_RESOURCE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPDestroyResource (2/2):
     * 'resourceId': The resource ID that shall be unregistered.
     */
    byte TAG_DESTROY_RESOURCE_RESOURCE_ID = (byte) 0x81;

    /**
     * Param-Tag for CSPConfigureResource (1/7):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_CONFIGURE_RESOURCE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPConfigureResource (2/7):
     * 'resourceId': The resource to be modified.
     */
    byte TAG_CONFIGURE_RESOURCE_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPConfigureResource (3/7):
     * 'accessControl': The access control configuration for the resource. (OPTIONAL)
     */
    byte TAG_CONFIGURE_RESOURCE_ACCESS_CONTROL = (byte) 0xA2;
    /**
     * Param-Tag for CSPConfigureResource (4/7):
     * 'algorithms': The algorithm configuration of the resource. (OPTIONAL)
     */
    byte TAG_CONFIGURE_RESOURCE_ALGORITHMS = (byte) 0xA3;
    /**
     * Param-Tag for CSPConfigureResource (5/7):
     * 'counters': Usage counter or authentication counter configurations of the resource. (OPTIONAL)
     */
    byte TAG_CONFIGURE_RESOURCE_COUNTERS = (byte) 0xA4;
    /**
     * Param-Tag for CSPConfigureResource (6/7):
     * 'timers': Validity date, validity period or timeout configurations. (OPTIONAL)
     */
    byte TAG_CONFIGURE_RESOURCE_TIMERS = (byte) 0xA5;
    /**
     * Param-Tag for CSPConfigureResource (7/7):
     * 'resourceEvents': The events that shall be logged for this resource. (OPTIONAL)
     */
    byte TAG_CONFIGURE_RESOURCE_RESOURCE_EVENT = (byte) 0xA6;

    /**
     * Param-Tag for CSPSetup (1/8):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_SETUP_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSetup (2/8):
     * 'cspSettings': Version, name, attestation key and error handling of this CSP Instance. (OPTIONAL)
     */
    byte TAG_SETUP_SETTINGS = (byte) 0xA1;
    /**
     * Param-Tag for CSPSetup (3/8):
     * 'secureChannelSettings': Set the general secure channel authentication timeout. (OPTIONAL)
     */
    byte TAG_SETUP_SECURE_CHANNEL_SETTINGS = (byte) 0xA2;
    /**
     * Param-Tag for CSPSetup (4/8):
     * 'policySettings': Select policy mode for handling unavailable policy types. (OPTIONAL)
     */
    byte TAG_SETUP_POLICY_SETTINGS = (byte) 0xA3;
    /**
     * Param-Tag for CSPSetup (5/8):
     * 'counterSettings': Select counter mode for handling unavailable counter types and sizes. (OPTIONAL)
     */
    byte TAG_SETUP_COUNTER_SETTINGS = (byte) 0xA4;
    /**
     * Param-Tag for CSPSetup (6/8):
     * 'timeSettings': Configure time management and handling of unavailable time. (OPTIONAL)
     */
    byte TAG_SETUP_TIME_SETTINGS = (byte) 0xA5;
    /**
     * Param-Tag for CSPSetup (7/8):
     * 'auditSettings': Configure audit event logging and handling of unavailable event types. (OPTIONAL)
     */
    byte TAG_SETUP_AUDIT_SETTINGS = (byte) 0xA6;
    /**
     * Param-Tag for CSPSetup (8/8):
     * 'fieldSettings': Select field mode for handling unavailable signature fields. (OPTIONAL)
     */
    byte TAG_SETUP_FIELD_SETTINGS = (byte) 0xA7;

    /**
     * Param-Tag for CSPActivate (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_ACTIVATE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPActivate (2/2):
     * 'configVersion': Custom version of the CSP Configuration chosen by the CSP Admin. (OPTIONAL)
     */
    byte TAG_ACTIVATE_CONFIG_VERSION = (byte) 0x81;

    /**
     * Param-Tag for CSPDeactivate (1/1):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_DEACTIVATE_PROTOCOL_VERSION = (byte) 0x80;

    /**
     * Param-Tag for CSPGetConfiguration (1/1):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_GET_CONFIGURATION_PROTOCOL_VERSION = (byte) 0x80;

    /**
     * Param-Tag for CSPGetConfigurationResponse (1/2):
     * 'cspProtocolVersion': Version of the CSP Admin Protocol used.
     */
    byte TAG_GET_CONFIGURATION_RESPONSE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPGetConfigurationResponse (2/2):
     * 'cspConfiguration': CSP Configuration of the entire CSP Instance.
     */
    byte TAG_GET_CONFIGURATION_RESPONSE_CONFIGURATION = (byte) 0xA1;

    /**
     * Param-Tag for CSPSetValue (1/6):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_SET_VALUE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSetValue (2/6):
     * 'resourceId': The identifier of the resource to set the value for.
     */
    byte TAG_SET_VALUE_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPSetValue (3/6):
     * 'decryptionResourceId': If set, the data is decrypted before being assigned to the resource. (OPTIONAL)
     */
    byte TAG_SET_VALUE_RESOURCE_ID_B = (byte) 0x82;
    /**
     * Param-Tag for CSPSetValue (4/6):
     * 'data': The value of the resource.
     */
    byte TAG_SET_VALUE_OCTET_STRING = (byte) 0x83;
    /**
     * Param-Tag for CSPSetValue (5/6):
     * 'initializationData': Algorithm-specific initialization data for decryption, e.g., iv data. (OPTIONAL)
     */
    byte TAG_SET_VALUE_OCTET_STRING_B = (byte) 0x84;
    /**
     * Param-Tag for CSPSetValue (6/6):
     * 'inTransport': Is this an initial value requiring change (only for passwords)?
     */
    byte TAG_SET_VALUE_BOOLEAN = (byte) 0x85;

    /**
     * Param-Tag for CSPClientCommand (1/1):
     * 'clientCommandChoice': 
     */
    byte TAG_CLIENT_CLIENT_COMMAND_CHOICE = (byte) 0xA0;

    /**
     * Param-Tag for CSPProcessSecurity (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_PROCESS_SECURITY_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPProcessSecurity (2/2):
     * 'apduData': APDU data for processing security.
     */
    byte TAG_PROCESS_SECURITY_OCTET_STRING = (byte) 0x81;

    /**
     * Param-Tag for CSPProcessSecurityResponse (1/1):
     * 'outputData': Output APDU resulting from secure channel processing.
     */
    byte TAG_PROCESS_SECURITY_RESPONSE_OCTET_STRING = (byte) 0x80;

    /**
     * Param-Tag for CSPSign (1/3):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_SIGN_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSign (2/3):
     * 'signingResourceId': The resource ID used to compute the signature.
     */
    byte TAG_SIGN_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPSign (3/3):
     * 'inputData': The data to sign.
     */
    byte TAG_SIGN_OCTET_STRING = (byte) 0x82;

    /**
     * Param-Tag for CSPSignResponse (1/1):
     * 'signature': 
     */
    byte TAG_SIGN_RESPONSE_SIGNATURE = (byte) 0x80;

    /**
     * Param-Tag for CSPVerifySignature (1/4):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_VERIFY_SIGNATURE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPVerifySignature (2/4):
     * 'signingResourceId': The resource ID used to compute the signature.
     */
    byte TAG_VERIFY_SIGNATURE_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPVerifySignature (3/4):
     * 'data': The signed data.
     */
    byte TAG_VERIFY_SIGNATURE_OCTET_STRING = (byte) 0x82;
    /**
     * Param-Tag for CSPVerifySignature (4/4):
     * 'signature': The signature to verify.
     */
    byte TAG_VERIFY_SIGNATURE_SIGNATURE = (byte) 0x83;

    /**
     * Param-Tag for CSPVerifySignatureResponse (1/1):
     * 'response': 
     */
    byte TAG_VERIFY_SIGNATURE_RESPONSE_BOOLEAN = (byte) 0x80;

    /**
     * Param-Tag for CSPEncrypt (1/4):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_ENCRYPT_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPEncrypt (2/4):
     * 'keyResourceId': The resource ID used to encrypt the data.
     */
    byte TAG_ENCRYPT_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPEncrypt (3/4):
     * 'initializationData': Algorithm-specific initialization data for encryption, e.g., IV data. (OPTIONAL)
     */
    byte TAG_ENCRYPT_OCTET_STRING = (byte) 0x82;
    /**
     * Param-Tag for CSPEncrypt (4/4):
     * 'inputData': The data to encrypt.
     */
    byte TAG_ENCRYPT_OCTET_STRING_B = (byte) 0x83;

    /**
     * Param-Tag for CSPDecrypt (1/4):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_DECRYPT_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPDecrypt (2/4):
     * 'keyResourceId': The resource ID used to decrypt the data.
     */
    byte TAG_DECRYPT_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPDecrypt (3/4):
     * 'initializationData': Algorithm-specific initialization data for decryption, e.g., IV data. (OPTIONAL)
     */
    byte TAG_DECRYPT_OCTET_STRING = (byte) 0x82;
    /**
     * Param-Tag for CSPDecrypt (4/4):
     * 'inputData': The data to decrypt.
     */
    byte TAG_DECRYPT_OCTET_STRING_B = (byte) 0x83;

    /**
     * Param-Tag for CSPResourceAttestation (1/4):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_RESOURCE_ATTESTATION_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPResourceAttestation (2/4):
     * 'attestationType': The attestation type used.
     */
    byte TAG_RESOURCE_ATTESTATION_RESOURCE_ATTESTATION_TYPE = (byte) 0x81;
    /**
     * Param-Tag for CSPResourceAttestation (3/4):
     * 'attestationResourceId': The resource ID used to create the attestation signature.
     */
    byte TAG_RESOURCE_ATTESTATION_RESOURCE_ID = (byte) 0x82;
    /**
     * Param-Tag for CSPResourceAttestation (4/4):
     * 'inputData': Additional input data to be included in the attestation.
     */
    byte TAG_RESOURCE_ATTESTATION_OCTET_STRING = (byte) 0x83;

    /**
     * Param-Tag for CSPClearResource (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_CLEAR_RESOURCE_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPClearResource (2/2):
     * 'resourceId': The identifier of the resource that shall be cleared.
     */
    byte TAG_CLEAR_RESOURCE_RESOURCE_ID = (byte) 0x81;

    /**
     * Param-Tag for CSPSystemAttestation (1/3):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_SYSTEM_ATTESTATION_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSystemAttestation (2/3):
     * 'attestationType': CASD-based CSP platform or CSP-specific config attestation.
     */
    byte TAG_SYSTEM_ATTESTATION_SYSTEM_ATTESTATION_TYPE = (byte) 0x81;
    /**
     * Param-Tag for CSPSystemAttestation (3/3):
     * 'challenge': Challenge for verification of attestation integrity. (OPTIONAL)
     */
    byte TAG_SYSTEM_ATTESTATION_CHALLENGE = (byte) 0x82;

    /**
     * Param-Tag for CSPGenerateKey (1/2):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_GENERATE_KEY_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPGenerateKey (2/2):
     * 'keyResourceId': The key for which the value should be generated.
     */
    byte TAG_GENERATE_KEY_RESOURCE_ID = (byte) 0x81;

    /**
     * Param-Tag for CSPComputePublicKey (1/3):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_COMPUTE_PUBLIC_KEY_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPComputePublicKey (2/3):
     * 'privateResourceId': The corresponding private key that is already initialized.
     */
    byte TAG_COMPUTE_PUBLIC_KEY_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPComputePublicKey (3/3):
     * 'publicResourceId': The public key that shall be computed.
     */
    byte TAG_COMPUTE_PUBLIC_KEY_RESOURCE_ID_B = (byte) 0x82;

    /**
     * Param-Tag for CSPDeriveKey (1/4):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_DERIVE_KEY_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPDeriveKey (2/4):
     * 'sourceResourceId': The resource that is base source for key derivation.
     */
    byte TAG_DERIVE_KEY_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPDeriveKey (3/4):
     * 'destResourceId': The destination resource to store the derived key value.
     */
    byte TAG_DERIVE_KEY_RESOURCE_ID_B = (byte) 0x82;
    /**
     * Param-Tag for CSPDeriveKey (4/4):
     * 'inputData': Additional input data given into the derivation algorithm
     */
    byte TAG_DERIVE_KEY_OCTET_STRING = (byte) 0x83;

    /**
     * Param-Tag for CSPSetTime (1/3):
     * 'cspProtocolVersion': Minimum API level required for the CSP Protocol.
     */
    byte TAG_SET_TIME_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSetTime (2/3):
     * 'newTime': The new reference time.
     */
    byte TAG_SET_TIME_TIMESTAMP = (byte) 0x81;
    /**
     * Param-Tag for CSPSetTime (3/3):
     * 'signature': Signature to verify the authenticity of the new reference time. (OPTIONAL)
     */
    byte TAG_SET_TIME_SIGNATURE = (byte) 0x82;

    /**
     * Param-Tag for CSPSetTimeResponse (1/1):
     * 'response': 
     */
    byte TAG_SET_TIME_RESPONSE_BOOLEAN = (byte) 0x80;

    /**
     * Param-Tag for CSPCoreSupport (1/1):
     * 'errorModes': CSP error handling modes. (OPTIONAL)
     */
    byte TAG_CORE_SUPPORT_ERROR_MODE = (byte) 0xA0;

    /**
     * Param-Tag for CSPSettings (1/4):
     * 'configName': Custom name of the CSP Configuration chosen by the CSP Admin.
     */
    byte TAG_SETTINGS_CONFIG_NAME = (byte) 0x80;
    /**
     * Param-Tag for CSPSettings (2/4):
     * 'configVersion': Custom version of the CSP Configuration chosen by the CSP Admin. (OPTIONAL)
     */
    byte TAG_SETTINGS_CONFIG_VERSION = (byte) 0x81;
    /**
     * Param-Tag for CSPSettings (3/4):
     * 'configAttestationKey': The key that shall be used to compute the config attestation. (OPTIONAL)
     */
    byte TAG_SETTINGS_RESOURCE_ID = (byte) 0x82;
    /**
     * Param-Tag for CSPSettings (4/4):
     * 'errorMode': Specify how the CSP shall handle exceptions. (OPTIONAL)
     */
    byte TAG_SETTINGS_ERROR_MODE = (byte) 0x83;

    /**
     * Param-Tag for CSPConfiguration (1/11):
     * 'cspMode': Indicates whether this CSP configuration is currently activated. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_MODE = (byte) 0x80;
    /**
     * Param-Tag for CSPConfiguration (2/11):
     * 'cspSettings': Name, version, attestation key and error handling of the CSP Instance. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_SETTINGS = (byte) 0xA1;
    /**
     * Param-Tag for CSPConfiguration (3/11):
     * 'cspPlatform': Static (read-only) information about the CSP platform.
     */
    byte TAG_CONFIGURATION_PLATFORM = (byte) 0xA2;
    /**
     * Param-Tag for CSPConfiguration (4/11):
     * 'clients': List of CSP Clients registered to this CSP Instance.
     */
    byte TAG_CONFIGURATION_CLIENT = (byte) 0xA3;
    /**
     * Param-Tag for CSPConfiguration (5/11):
     * 'resources': List of resources along with their cryptographic configurations.
     */
    byte TAG_CONFIGURATION_RESOURCE = (byte) 0xA4;
    /**
     * Param-Tag for CSPConfiguration (6/11):
     * 'secureChannelSettings': Set the general secure channel authentication timeout. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_SECURE_CHANNEL_SETTINGS = (byte) 0xA5;
    /**
     * Param-Tag for CSPConfiguration (7/11):
     * 'policySettings': Select policy mode for handling unavailable policy types. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_POLICY_SETTINGS = (byte) 0xA6;
    /**
     * Param-Tag for CSPConfiguration (8/11):
     * 'counterSettings': Select counter mode for handling unavailable counter types and sizes. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_COUNTER_SETTINGS = (byte) 0xA7;
    /**
     * Param-Tag for CSPConfiguration (9/11):
     * 'timeSettings': Configure time management and handling of unavailable time. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_TIME_SETTINGS = (byte) 0xA8;
    /**
     * Param-Tag for CSPConfiguration (10/11):
     * 'auditSettings': Configure audit event logging and handling of unavailable event types. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_AUDIT_SETTINGS = (byte) 0xA9;
    /**
     * Param-Tag for CSPConfiguration (11/11):
     * 'fieldSettings': Select field mode for handling unavailable signature fields. (OPTIONAL)
     */
    byte TAG_CONFIGURATION_FIELD_SETTINGS = (byte) 0xAA;

    /**
     * Param-Tag for CSPPlatform (1/5):
     * 'cspProtocolVersion': Version of the CSP Protocol (Version).
     */
    byte TAG_PLATFORM_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPPlatform (2/5):
     * 'cspApiVersion': Version of the Java Card CSP API (Major, Minor, Patch).
     */
    byte TAG_PLATFORM_A_P_I_VERSION = (byte) 0x81;
    /**
     * Param-Tag for CSPPlatform (3/5):
     * 'cspELFVersion': Version of the CSP ELF file (Major, Minor).
     */
    byte TAG_PLATFORM_ELF_VERSION = (byte) 0x82;
    /**
     * Param-Tag for CSPPlatform (4/5):
     * 'platformName': Name and version of the SE platform encoded in ASCII.
     */
    byte TAG_PLATFORM_OCTET_STRING = (byte) 0x83;
    /**
     * Param-Tag for CSPPlatform (5/5):
     * 'cspInstanceAID': AID of the CSP Instance.
     */
    byte TAG_PLATFORM_AID = (byte) 0x84;

    /**
     * Param-Tag for CSPResourceSupport (1/1):
     * 'resourceTypes': Supported resource types. (OPTIONAL)
     */
    byte TAG_RESOURCE_SUPPORT_RESOURCE_TYPE = (byte) 0xA0;

    /**
     * Param-Tag for CSPResource (1/8):
     * 'resourceId': Unique identifier of the resource choosen by the CSP Admin.
     */
    byte TAG_RESOURCE_RESOURCE_ID = (byte) 0x80;
    /**
     * Param-Tag for CSPResource (2/8):
     * 'resourceParams': The resource-specific parameters (e.g., key type, curve, min-size).
     */
    byte TAG_RESOURCE_RESOURCE_PARAMS = (byte) 0xA1;
    /**
     * Param-Tag for CSPResource (3/8):
     * 'usageType': The usage type specifying the CSP operations sllowed for the resource.
     */
    byte TAG_RESOURCE_USAGE_TYPE = (byte) 0x82;
    /**
     * Param-Tag for CSPResource (4/8):
     * 'accessControl': Access conrol configuration for the resource. (OPTIONAL)
     */
    byte TAG_RESOURCE_ACCESS_CONTROL = (byte) 0xA3;
    /**
     * Param-Tag for CSPResource (5/8):
     * 'algorithms': The algorithm configuration of the resource. (OPTIONAL)
     */
    byte TAG_RESOURCE_ALGORITHMS = (byte) 0xA4;
    /**
     * Param-Tag for CSPResource (6/8):
     * 'counters':  (OPTIONAL)
     */
    byte TAG_RESOURCE_COUNTERS = (byte) 0xA5;
    /**
     * Param-Tag for CSPResource (7/8):
     * 'timers':  (OPTIONAL)
     */
    byte TAG_RESOURCE_TIMERS = (byte) 0xA6;
    /**
     * Param-Tag for CSPResource (8/8):
     * 'resourceEvents': The events that shall be audited for this resource. (OPTIONAL)
     */
    byte TAG_RESOURCE_RESOURCE_EVENT = (byte) 0xA7;

    /**
     * Param-Tag for CSPClient (1/4):
     * 'clientId': An identifier of the CSP Client, chosen by the CSP Admin. (OPTIONAL)
     */
    byte TAG_CLIENT_INTEGER = (byte) 0x80;
    /**
     * Param-Tag for CSPClient (2/4):
     * 'clientApplication': The Client Application registered to the CSP. (OPTIONAL)
     */
    byte TAG_CLIENT_CLIENT_APPLICATION = (byte) 0xA1;
    /**
     * Param-Tag for CSPClient (3/4):
     * 'authProtocol': Restrict access to CSP services when a sec channel is fully established. (OPTIONAL)
     */
    byte TAG_CLIENT_PROTOCOL_TYPE = (byte) 0x82;
    /**
     * Param-Tag for CSPClient (4/4):
     * 'authResources': Resources required for the configured authProtocol. (OPTIONAL)
     */
    byte TAG_CLIENT_RESOURCE_ID = (byte) 0xA3;

    /**
     * Param-Tag for CSPClientApplication (1/4):
     * 'applicationAID': AID of the Client Application.
     */
    byte TAG_CLIENT_APPLICATION_AID = (byte) 0x80;
    /**
     * Param-Tag for CSPClientApplication (2/4):
     * 'loadFileDataBlockHash': Hash of the load data file block of the Client Application. (OPTIONAL)
     */
    byte TAG_CLIENT_APPLICATION_OCTET_STRING = (byte) 0x81;
    /**
     * Param-Tag for CSPClientApplication (3/4):
     * 'requiredDAPVerification': Client Application must be DAP-verified during load. (OPTIONAL)
     */
    byte TAG_CLIENT_APPLICATION_BOOLEAN = (byte) 0x82;
    /**
     * Param-Tag for CSPClientApplication (4/4):
     * 'applicationSD': AID of the SD of the Client Application.
     */
    byte TAG_CLIENT_APPLICATION_APPLICATION_S_D = (byte) 0xA3;

    /**
     * Param-Tag for CSPAccessControl (1/3):
     * 'accessControlRules': ACR bitmask. (OPTIONAL)
     */
    byte TAG_ACCESS_CONTROL_ACCESS_CONTROL_RULES = (byte) 0x80;
    /**
     * Param-Tag for CSPAccessControl (2/3):
     * 'owner': CSP Client that owns this resource . (OPTIONAL)
     */
    byte TAG_ACCESS_CONTROL_CLIENT_REFERENCE = (byte) 0xA1;
    /**
     * Param-Tag for CSPAccessControl (3/3):
     * 'policies': Dynamic policy rules. (OPTIONAL)
     */
    byte TAG_ACCESS_CONTROL_POLICY = (byte) 0xA2;

    /**
     * Param-Tag for CSPCipherSupport (1/2):
     * 'paddingsAlgorithms': Padding algorithms. (OPTIONAL)
     */
    byte TAG_CIPHER_SUPPORT_PADDING_ALGORITHM = (byte) 0xA0;
    /**
     * Param-Tag for CSPCipherSupport (2/2):
     * 'cipherAlgorithms': Cipher algorithms. (OPTIONAL)
     */
    byte TAG_CIPHER_SUPPORT_CIPHER_ALGORITHM = (byte) 0xA1;

    /**
     * Param-Tag for CSPCipherAlgorithms (1/2):
     * 'cipherAlgorithm': The cipher algorithm.
     */
    byte TAG_CIPHER_ALGORITHMS_CIPHER_ALGORITHM = (byte) 0x80;
    /**
     * Param-Tag for CSPCipherAlgorithms (2/2):
     * 'paddingAlgorithm': The padding algorithm. (OPTIONAL)
     */
    byte TAG_CIPHER_ALGORITHMS_PADDING_ALGORITHM = (byte) 0x81;

    /**
     * Param-Tag for CSPSignatureSupport (1/2):
     * 'messageDigestAlgorithms': Message digest algorithms. (OPTIONAL)
     */
    byte TAG_SIGNATURE_SUPPORT_MESSAGE_DIGEST_ALGORITHM = (byte) 0xA0;
    /**
     * Param-Tag for CSPSignatureSupport (2/2):
     * 'signatureAlgorithms': Signature algorithms. (OPTIONAL)
     */
    byte TAG_SIGNATURE_SUPPORT_SIGNATURE_ALGORITHM = (byte) 0xA1;

    /**
     * Param-Tag for CSPSignatureAlgorithms (1/3):
     * 'signatureAlgorithm': The signature algorithm.
     */
    byte TAG_SIGNATURE_ALGORITHMS_SIGNATURE_ALGORITHM = (byte) 0x80;
    /**
     * Param-Tag for CSPSignatureAlgorithms (2/3):
     * 'paddingAlgorithm': The padding algorithm. (OPTIONAL)
     */
    byte TAG_SIGNATURE_ALGORITHMS_PADDING_ALGORITHM = (byte) 0x81;
    /**
     * Param-Tag for CSPSignatureAlgorithms (3/3):
     * 'messageDigestAlgorithm': The message digest algorithm. (OPTIONAL)
     */
    byte TAG_SIGNATURE_ALGORITHMS_MESSAGE_DIGEST_ALGORITHM = (byte) 0x82;

    /**
     * Param-Tag for CSPSecureChannelSupport (1/2):
     * 'protocolTypes': Secure channel protocol types. (OPTIONAL)
     */
    byte TAG_SECURE_CHANNEL_SUPPORT_PROTOCOL_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPSecureChannelSupport (2/2):
     * 'securityFunctions': Secure channel security functions. (OPTIONAL)
     */
    byte TAG_SECURE_CHANNEL_SUPPORT_SECURITY_FUNCTION = (byte) 0x81;

    /**
     * Param-Tag for CSPSecureChannelSettings (1/1):
     * 'securityTimeout': Secure channel timeout in seconds (TIMER_SECURITY_TIMEOUT). (OPTIONAL)
     */
    byte TAG_SECURE_CHANNEL_SETTINGS_TIMEOUT = (byte) 0xA0;

    /**
     * Param-Tag for CSPSecureChannelAlgorithms (1/1):
     * 'securityFunction': The security function of the protocol.
     */
    byte TAG_SECURE_CHANNEL_ALGORITHMS_SECURITY_FUNCTION = (byte) 0x80;

    /**
     * Param-Tag for CSPAttestationSupport (1/1):
     * 'resourceAttestationTypes': Resource attestation types, such as Data or PoP attestations. (OPTIONAL)
     */
    byte TAG_ATTESTATION_SUPPORT_RESOURCE_ATTESTATION_TYPE = (byte) 0xA0;

    /**
     * Param-Tag for CSPAttestationAlgorithms (1/3):
     * 'signatureAlgorithms': The signature, padding and message digest algorithms.
     */
    byte TAG_ATTESTATION_ALGORITHMS_SIGNATURE_ALGORITHMS = (byte) 0xA0;
    /**
     * Param-Tag for CSPAttestationAlgorithms (2/3):
     * 'fieldsAddedAsPrefix': Add signature fields (e.g., counter) to the beginning of data to sign. (OPTIONAL)
     */
    byte TAG_ATTESTATION_ALGORITHMS_FIELD = (byte) 0xA1;
    /**
     * Param-Tag for CSPAttestationAlgorithms (3/3):
     * 'fieldsAddedAsSuffix': Add signature fields (e.g., counter) to the end of data to sign. (OPTIONAL)
     */
    byte TAG_ATTESTATION_ALGORITHMS_FIELD_B = (byte) 0xA2;

    /**
     * Param-Tag for CSPPlatformAttestation (1/2):
     * 'signedPlatformData': The attestation data to be signed, including tags and lengths.
     */
    byte TAG_PLATFORM_ATTESTATION_SIGNED_PLATFORM_DATA = (byte) 0xA0;
    /**
     * Param-Tag for CSPPlatformAttestation (2/2):
     * 'signature': Signature over the entire signedPlatformData according to [GP Amd A].
     */
    byte TAG_PLATFORM_ATTESTATION_SIGNATURE = (byte) 0x81;

    /**
     * Param-Tag for CSPSignedPlatformData (1/7):
     * 'cspProtocolVersion': Version of the CSP Admin Protocol used.
     */
    byte TAG_SIGNED_PLATFORM_DATA_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSignedPlatformData (2/7):
     * 'attestationType': The type of the attestation being computed (i.e., platform). (OPTIONAL)
     */
    byte TAG_SIGNED_PLATFORM_DATA_SYSTEM_ATTESTATION_TYPE = (byte) 0x81;
    /**
     * Param-Tag for CSPSignedPlatformData (3/7):
     * 'platform': Information about the CSP platform.
     */
    byte TAG_SIGNED_PLATFORM_DATA_PLATFORM = (byte) 0xA2;
    /**
     * Param-Tag for CSPSignedPlatformData (4/7):
     * 'platform-DLOA-XML': Platform DLOA XML according to A.1 / A.2.1 of [GP DLOA].
     */
    byte TAG_SIGNED_PLATFORM_DATA_OCTET_STRING = (byte) 0x83;
    /**
     * Param-Tag for CSPSignedPlatformData (5/7):
     * 'csp-application-DLOA-XML': Application DLOA according to A.1 / A.2.2 of [GP DLOA]. (OPTIONAL)
     */
    byte TAG_SIGNED_PLATFORM_DATA_OCTET_STRING_B = (byte) 0x84;
    /**
     * Param-Tag for CSPSignedPlatformData (6/7):
     * 'inputData': Input data, e.g. a challenge, provided within the command. (OPTIONAL)
     */
    byte TAG_SIGNED_PLATFORM_DATA_OCTET_STRING_C = (byte) 0x85;
    /**
     * Param-Tag for CSPSignedPlatformData (7/7):
     * 'SecurityEnvironmentTemplate': Data structure according to [GP Amd A] section 5.3.1.
     */
    byte TAG_SIGNED_PLATFORM_DATA_SECURITY_ENVIRONMENT_TEMPLATE = (byte) 0xA6;

    /**
     * Param-Tag for ClientApplicationInformation (1/4):
     * 'requestedSignatureMode': The signature mode selected by the CSP Application with init().
     */
    byte TAG_CLIENT_APPLICATION_INFORMATION_OCTET_STRING = (byte) 0x00;
    /**
     * Param-Tag for ClientApplicationInformation (2/4):
     * 'instanceAID': The AID of the CSP Application.
     */
    byte TAG_CLIENT_APPLICATION_INFORMATION_OCTET_STRING_B = (byte) 0x01;
    /**
     * Param-Tag for ClientApplicationInformation (3/4):
     * 'executableLoadFileAID': The AID of the CSP ELF.
     */
    byte TAG_CLIENT_APPLICATION_INFORMATION_OCTET_STRING_C = (byte) 0x02;
    /**
     * Param-Tag for ClientApplicationInformation (4/4):
     * 'executableLoadFileVersionNumber': The version of the CSP ELF; e.g., 2-byte major, minor for CAP file.
     */
    byte TAG_CLIENT_APPLICATION_INFORMATION_OCTET_STRING_D = (byte) 0x03;

    /**
     * Param-Tag for SecurityEnvironmentTemplate (1/3):
     * 'clientApplicationInformation': Information about the CSP Application.
     */
    byte TAG_SECURITY_ENVIRONMENT_TEMPLATE_CLIENT_APPLICATION_INFORMATION = (byte) 0x00;
    /**
     * Param-Tag for SecurityEnvironmentTemplate (2/3):
     * 'signatureAlgorithm': Information about the algorithm used by the CASD.
     */
    byte TAG_SECURITY_ENVIRONMENT_TEMPLATE_ALGORITHM_IDENTIFIER = (byte) 0x01;
    /**
     * Param-Tag for SecurityEnvironmentTemplate (3/3):
     * 'keyIdentifier': Identifier of the PK.CASD-SIGN.AUT to verify the signature ([GP Amd A]).
     */
    byte TAG_SECURITY_ENVIRONMENT_TEMPLATE_OCTET_STRING = (byte) 0x02;

    /**
     * Param-Tag for AlgorithmIdentifier (1/1):
     * 'algorithm': The OID of an ECDSA algorithm as specified in [RFC 5758] section 3.2.
     */
    byte TAG_ALGORITHM_IDENTIFIER_OBJECT_IDENTIFIER = (byte) 0x80;

    /**
     * Param-Tag for CSPConfigAttestation (1/4):
     * 'signedConfigData': The attestation data to be signed, including tags and lengths.
     */
    byte TAG_CONFIG_ATTESTATION_SIGNED_CONFIG_DATA = (byte) 0xA0;
    /**
     * Param-Tag for CSPConfigAttestation (2/4):
     * 'signature': Signature over the signedConfigData using the config attestation key.
     */
    byte TAG_CONFIG_ATTESTATION_SIGNATURE = (byte) 0x81;
    /**
     * Param-Tag for CSPConfigAttestation (3/4):
     * 'signatureAlgorithm': The algorithm used to sign the data.
     */
    byte TAG_CONFIG_ATTESTATION_SIGNATURE_ALGORITHMS = (byte) 0xA2;
    /**
     * Param-Tag for CSPConfigAttestation (4/4):
     * 'signaturKeySizeOrCurve': Key parameters of the attestation key.
     */
    byte TAG_CONFIG_ATTESTATION_KEY_SIZE_OR_CURVE = (byte) 0xA3;

    /**
     * Param-Tag for CSPSignedConfigData (1/8):
     * 'cspProtocolVersion': Version of the CSP Admin Protocol used.
     */
    byte TAG_SIGNED_CONFIG_DATA_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSignedConfigData (2/8):
     * 'attestationType': The type of the attestation being computed (i.e., config). (OPTIONAL)
     */
    byte TAG_SIGNED_CONFIG_DATA_SYSTEM_ATTESTATION_TYPE = (byte) 0x81;
    /**
     * Param-Tag for CSPSignedConfigData (3/8):
     * 'fieldsAddedAsPrefix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_SIGNED_CONFIG_DATA_FIELD = (byte) 0xA2;
    /**
     * Param-Tag for CSPSignedConfigData (4/8):
     * 'configName': Custom name set by the CSP Admin via CSPSetup.
     */
    byte TAG_SIGNED_CONFIG_DATA_CONFIG_NAME = (byte) 0x83;
    /**
     * Param-Tag for CSPSignedConfigData (5/8):
     * 'configVersion': Custom version set by the CSP Admin via CSPSetup.
     */
    byte TAG_SIGNED_CONFIG_DATA_CONFIG_VERSION = (byte) 0x84;
    /**
     * Param-Tag for CSPSignedConfigData (6/8):
     * 'cspPlatform': Information about the CSP platform.
     */
    byte TAG_SIGNED_CONFIG_DATA_PLATFORM = (byte) 0xA5;
    /**
     * Param-Tag for CSPSignedConfigData (7/8):
     * 'inputData': Input data, e.g. a challenge, provided within the command.
     */
    byte TAG_SIGNED_CONFIG_DATA_OCTET_STRING = (byte) 0x86;
    /**
     * Param-Tag for CSPSignedConfigData (8/8):
     * 'fieldsAddedAsSuffix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_SIGNED_CONFIG_DATA_FIELD_B = (byte) 0xA7;

    /**
     * Param-Tag for CSPDataAttestation (1/4):
     * 'signedData': The attestation data to be signed, including tags and lengths.
     */
    byte TAG_DATA_ATTESTATION_SIGNED_DATA = (byte) 0xA0;
    /**
     * Param-Tag for CSPDataAttestation (2/4):
     * 'signature': Signature over the signedData using the attestation key.
     */
    byte TAG_DATA_ATTESTATION_SIGNATURE = (byte) 0x81;
    /**
     * Param-Tag for CSPDataAttestation (3/4):
     * 'signatureAlgorithm': The algorithm used to sign the data.
     */
    byte TAG_DATA_ATTESTATION_SIGNATURE_ALGORITHMS = (byte) 0xA2;
    /**
     * Param-Tag for CSPDataAttestation (4/4):
     * 'signaturKeySizeOrCurve': Key parameters of the attestation key.
     */
    byte TAG_DATA_ATTESTATION_KEY_SIZE_OR_CURVE = (byte) 0xA3;

    /**
     * Param-Tag for CSPSignedData (1/6):
     * 'cspProtocolVersion': Version of the CSP Admin Protocol used.
     */
    byte TAG_SIGNED_DATA_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSignedData (2/6):
     * 'attestationType': The type of the attestation being computed (i.e., data attestation). (OPTIONAL)
     */
    byte TAG_SIGNED_DATA_RESOURCE_ATTESTATION_TYPE = (byte) 0x81;
    /**
     * Param-Tag for CSPSignedData (3/6):
     * 'fieldsAddedAsPrefix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_SIGNED_DATA_FIELD = (byte) 0xA2;
    /**
     * Param-Tag for CSPSignedData (4/6):
     * 'inputData': The input data, e.g. a challenge, provided within the command.
     */
    byte TAG_SIGNED_DATA_OCTET_STRING = (byte) 0x83;
    /**
     * Param-Tag for CSPSignedData (5/6):
     * 'resourceValue': CSP-internal resource value: public key, counter or timer. (OPTIONAL)
     */
    byte TAG_SIGNED_DATA_RESOURCE_VALUE = (byte) 0x84;
    /**
     * Param-Tag for CSPSignedData (6/6):
     * 'fieldsAddedAsSuffix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_SIGNED_DATA_FIELD_B = (byte) 0xA5;

    /**
     * Param-Tag for CSPKeyPoPAttestation (1/6):
     * 'signedPoPData': The attestation data to be signed, including tags and lengths.
     */
    byte TAG_KEY_POP_ATTESTATION_SIGNED_POP_DATA = (byte) 0xA0;
    /**
     * Param-Tag for CSPKeyPoPAttestation (2/6):
     * 'signature': Signature over the entire signedPoPData using the attestation key.
     */
    byte TAG_KEY_POP_ATTESTATION_SIGNATURE = (byte) 0x81;
    /**
     * Param-Tag for CSPKeyPoPAttestation (3/6):
     * 'signatureAlgorithm': The algorithm used to sign the signedPoPData.
     */
    byte TAG_KEY_POP_ATTESTATION_SIGNATURE_ALGORITHMS = (byte) 0xA2;
    /**
     * Param-Tag for CSPKeyPoPAttestation (4/6):
     * 'signaturKeySizeOrCurve': Key parameters of attestation key.
     */
    byte TAG_KEY_POP_ATTESTATION_KEY_SIZE_OR_CURVE = (byte) 0xA3;
    /**
     * Param-Tag for CSPKeyPoPAttestation (5/6):
     * 'popSignatureAlgorithm': The algorithm used to sign the popData.
     */
    byte TAG_KEY_POP_ATTESTATION_SIGNATURE_ALGORITHMS_B = (byte) 0xA4;
    /**
     * Param-Tag for CSPKeyPoPAttestation (6/6):
     * 'popSignaturKeySizeOrCurve': Key parameters of the private key.
     */
    byte TAG_KEY_POP_ATTESTATION_KEY_SIZE_OR_CURVE_B = (byte) 0xA5;

    /**
     * Param-Tag for CSPSignedPoPData (1/3):
     * 'cspProtocolVersion': Version of the CSP Admin Protocol used.
     */
    byte TAG_SIGNED_POP_DATA_PROTOCOL_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPSignedPoPData (2/3):
     * 'popData': Proof Of Possession data to be signed, including tags and lengths.
     */
    byte TAG_SIGNED_POP_DATA_POP_DATA = (byte) 0xA1;
    /**
     * Param-Tag for CSPSignedPoPData (3/3):
     * 'popDataSignature': Signature over the popData using the private key.
     */
    byte TAG_SIGNED_POP_DATA_SIGNATURE = (byte) 0x82;

    /**
     * Param-Tag for CSPPopData (1/6):
     * 'attestationType': The type of the attestation being computed (i.e., PoP). (OPTIONAL)
     */
    byte TAG_POP_DATA_RESOURCE_ATTESTATION_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPPopData (2/6):
     * 'fieldsAddedAsPrefix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_POP_DATA_FIELD = (byte) 0xA1;
    /**
     * Param-Tag for CSPPopData (3/6):
     * 'publicKey': Public key value to attest.
     */
    byte TAG_POP_DATA_RESOURCE_VALUE = (byte) 0x82;
    /**
     * Param-Tag for CSPPopData (4/6):
     * 'publicAttestationKey': Public att. key to verify the signature over signedPoPData. (OPTIONAL)
     */
    byte TAG_POP_DATA_RESOURCE_VALUE_B = (byte) 0x83;
    /**
     * Param-Tag for CSPPopData (5/6):
     * 'inputData': Input data, e.g., a challenge, provided within the command.
     */
    byte TAG_POP_DATA_OCTET_STRING = (byte) 0x84;
    /**
     * Param-Tag for CSPPopData (6/6):
     * 'fieldsAddedAsSuffix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_POP_DATA_FIELD_B = (byte) 0xA5;

    /**
     * Param-Tag for CSPKeySupport (1/4):
     * 'keySizes': Key types, such as AES, RSA or ECC with key sizes. (OPTIONAL)
     */
    byte TAG_KEY_SUPPORT_KEY_SIZE = (byte) 0xA0;
    /**
     * Param-Tag for CSPKeySupport (2/4):
     * 'curves': Curves / ECC domain parameter sets. (OPTIONAL)
     */
    byte TAG_KEY_SUPPORT_CURVE = (byte) 0xA1;
    /**
     * Param-Tag for CSPKeySupport (3/4):
     * 'keyDerivationAlgorithms': Key derivation alorithms. (OPTIONAL)
     */
    byte TAG_KEY_SUPPORT_KEY_DERIVATION_ALGORITHM = (byte) 0xA2;
    /**
     * Param-Tag for CSPKeySupport (4/4):
     * 'keyAgreementSchemes': Key agreement schemes. (OPTIONAL)
     */
    byte TAG_KEY_SUPPORT_KEY_AGREEMENT_SCHEME = (byte) 0xA3;

    /**
     * Param-Tag for CSPKey (1/4):
     * 'type': The cryptographic keyType.
     */
    byte TAG_KEY_KEY_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPKey (2/4):
     * 'size': The cryptographic keySize; also mandatory for ECC keys.
     */
    byte TAG_KEY_KEY_SIZE = (byte) 0x81;
    /**
     * Param-Tag for CSPKey (3/4):
     * 'curve': ECC curve parameters; only relevant for ECC keys. (OPTIONAL)
     */
    byte TAG_KEY_CURVE = (byte) 0x82;
    /**
     * Param-Tag for CSPKey (4/4):
     * 'transient': Flag indicating the key is transient. (OPTIONAL)
     */
    byte TAG_KEY_BOOLEAN = (byte) 0x83;

    /**
     * Param-Tag for CSPKeyDerivationAlgorithms (1/2):
     * 'keyDerivationAlgorithm': The key derivation algorithm.
     */
    byte TAG_KEY_DERIVATION_ALGORITHMS_KEY_DERIVATION_ALGORITHM = (byte) 0x80;
    /**
     * Param-Tag for CSPKeyDerivationAlgorithms (2/2):
     * 'keyDerivationHashAlgorithm': The hash algorithm used for the key derivation. (OPTIONAL)
     */
    byte TAG_KEY_DERIVATION_ALGORITHMS_MESSAGE_DIGEST_ALGORITHM = (byte) 0x81;

    /**
     * Param-Tag for CSPCertificateSupport (1/1):
     * 'certificateTypes': Certificate types, such as CVC or X.509. (OPTIONAL)
     */
    byte TAG_CERTIFICATE_SUPPORT_CERTIFICATE_TYPE = (byte) 0xA0;

    /**
     * Param-Tag for CSPCertificate (1/1):
     * 'type': The certificateType of the certificate.
     */
    byte TAG_CERTIFICATE_CERTIFICATE_TYPE = (byte) 0x80;

    /**
     * Param-Tag for CSPPasswordSupport (1/1):
     * 'passwordTypes': Password types, such as numbers only or strong with special characters. (OPTIONAL)
     */
    byte TAG_PASSWORD_SUPPORT_PASSWORD_TYPE = (byte) 0xA0;

    /**
     * Param-Tag for CSPPassword (1/4):
     * 'type': The passwordType paramter of the password.
     */
    byte TAG_PASSWORD_PASSWORD_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPPassword (2/4):
     * 'minSize': Minimum number of password characters allowed. (OPTIONAL)
     */
    byte TAG_PASSWORD_INTEGER = (byte) 0x81;
    /**
     * Param-Tag for CSPPassword (3/4):
     * 'maxSize': Maximum number of password characters allowed. (OPTIONAL)
     */
    byte TAG_PASSWORD_INTEGER_B = (byte) 0x82;
    /**
     * Param-Tag for CSPPassword (4/4):
     * 'tryLimit': Incorrect password attempts allowed before blocked (disabled if 0xFF). (OPTIONAL)
     */
    byte TAG_PASSWORD_INTEGER_C = (byte) 0x83;

    /**
     * Param-Tag for CSPCounterSupport (1/4):
     * 'counterModes': Counter operation modes to specify the handling of unsupported counters. (OPTIONAL)
     */
    byte TAG_COUNTER_SUPPORT_COUNTER_MODE = (byte) 0xA0;
    /**
     * Param-Tag for CSPCounterSupport (2/4):
     * 'counterTypes': Counter types. (OPTIONAL)
     */
    byte TAG_COUNTER_SUPPORT_COUNTER_TYPE = (byte) 0xA1;
    /**
     * Param-Tag for CSPCounterSupport (3/4):
     * 'counterCapacitites': Counter capacitites. (OPTIONAL)
     */
    byte TAG_COUNTER_SUPPORT_COUNTER_CAPACITY = (byte) 0xA2;
    /**
     * Param-Tag for CSPCounterSupport (4/4):
     * 'largeCounterLimit': Maximum number of counters with large capacity. (OPTIONAL)
     */
    byte TAG_COUNTER_SUPPORT_INTEGER = (byte) 0x83;

    /**
     * Param-Tag for CSPCounterSettings (1/1):
     * 'counterMode': Select counter mode specify the handling of unavailable counter types.
     */
    byte TAG_COUNTER_SETTINGS_COUNTER_MODE = (byte) 0x80;

    /**
     * Param-Tag for CSPCounters (1/6):
     * 'usageCounter': Counter of type COUNT_USAGE. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER = (byte) 0xA0;
    /**
     * Param-Tag for CSPCounters (2/6):
     * 'blockUsageCounter': Counter of type COUNT_USAGE_PER_BLOCK. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER_B = (byte) 0xA1;
    /**
     * Param-Tag for CSPCounters (3/6):
     * 'successCounter': Counter of type COUNT_USAGE_SUCCESS_ONLY. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER_C = (byte) 0xA2;
    /**
     * Param-Tag for CSPCounters (4/6):
     * 'failureCounter': Counter of type COUNT_USAGE_FAILURE_ONLY. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER_D = (byte) 0xA3;
    /**
     * Param-Tag for CSPCounters (5/6):
     * 'authUsageCounter': Counter of type COUNT_AUTH_USAGE. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER_E = (byte) 0xA4;
    /**
     * Param-Tag for CSPCounters (6/6):
     * 'transportUsageCounter': Counter of type COUNT_TRANSPORT_USAGE. (OPTIONAL)
     */
    byte TAG_COUNTERS_COUNTER_F = (byte) 0xA5;

    /**
     * Param-Tag for CSPCounter (1/2):
     * 'counterCapacity': The structure of the counter defines the max increments supported. (OPTIONAL)
     */
    byte TAG_COUNTER_COUNTER_CAPACITY = (byte) 0x80;
    /**
     * Param-Tag for CSPCounter (2/2):
     * 'counterLimit': Maximum counter limit before the counter exceeds; is 0 when disabled. (OPTIONAL)
     */
    byte TAG_COUNTER_OCTET_STRING = (byte) 0x81;

    /**
     * Param-Tag for CSPTimeSupport (1/4):
     * 'timeModes': Time operation modes to specify the handling for unsupported time. (OPTIONAL)
     */
    byte TAG_TIME_SUPPORT_TIME_MODE = (byte) 0xA0;
    /**
     * Param-Tag for CSPTimeSupport (2/4):
     * 'timeSynchonization': Time synchronization strategies. (OPTIONAL)
     */
    byte TAG_TIME_SUPPORT_TIME_SYNCHRONIZATION = (byte) 0x81;
    /**
     * Param-Tag for CSPTimeSupport (3/4):
     * 'timerTypes': Timer types, such as validity date or authentication timeout. (OPTIONAL)
     */
    byte TAG_TIME_SUPPORT_TIMER_TYPE = (byte) 0xA2;
    /**
     * Param-Tag for CSPTimeSupport (4/4):
     * 'timeoutTypes': Timeout types to specify if a timeout timer is refreshed. (OPTIONAL)
     */
    byte TAG_TIME_SUPPORT_TIMEOUT_TYPE = (byte) 0xA3;

    /**
     * Param-Tag for CSPTimeSettings (1/3):
     * 'timeMode': Select time mode to specify the handling of unavailable system time. (OPTIONAL)
     */
    byte TAG_TIME_SETTINGS_TIME_MODE = (byte) 0x80;
    /**
     * Param-Tag for CSPTimeSettings (2/3):
     * 'timeSynchonization': Configure a strategy to syncronize the reference time. (OPTIONAL)
     */
    byte TAG_TIME_SETTINGS_TIME_SYNCHRONIZATION = (byte) 0x81;
    /**
     * Param-Tag for CSPTimeSettings (3/3):
     * 'timeVerificationKey': A public key to verify signatures of new timestamps. (OPTIONAL)
     */
    byte TAG_TIME_SETTINGS_RESOURCE_ID = (byte) 0x82;

    /**
     * Param-Tag for CSPTimers (1/4):
     * 'validityPeriod': Validity period for key or password (TIMER_VALIDITY_PERIOD). (OPTIONAL)
     */
    byte TAG_TIMERS_DURATION = (byte) 0x80;
    /**
     * Param-Tag for CSPTimers (2/4):
     * 'validityDate': Validity date for key or password (TIMER_VALIDITY_DATE). (OPTIONAL)
     */
    byte TAG_TIMERS_TIMESTAMP = (byte) 0x81;
    /**
     * Param-Tag for CSPTimers (3/4):
     * 'validityCertificate': Validity date from certificate (TIMER_VALIDITY_CERTIFICATE). (OPTIONAL)
     */
    byte TAG_TIMERS_BOOLEAN = (byte) 0x82;
    /**
     * Param-Tag for CSPTimers (4/4):
     * 'authTimeout': Authentication timeout for passwords (TIMER_AUTH_TIMEOUT). (OPTIONAL)
     */
    byte TAG_TIMERS_TIMEOUT = (byte) 0xA3;

    /**
     * Param-Tag for CSPTimeout (1/2):
     * 'timeoutValue': Maximum time limit before the timer expires.
     */
    byte TAG_TIMEOUT_OCTET_STRING = (byte) 0x80;
    /**
     * Param-Tag for CSPTimeout (2/2):
     * 'timeoutType': Specifys if the timeout value is re-computed on each resource usage. (OPTIONAL)
     */
    byte TAG_TIMEOUT_TIMEOUT_TYPE = (byte) 0x81;

    /**
     * Param-Tag for CSPAuditSupport (1/3):
     * 'auditModes': Audit operation modes to specify the handling for unsupported events. (OPTIONAL)
     */
    byte TAG_AUDIT_SUPPORT_AUDIT_MODE = (byte) 0xA0;
    /**
     * Param-Tag for CSPAuditSupport (2/3):
     * 'systemEvents': Event types of category "system event". (OPTIONAL)
     */
    byte TAG_AUDIT_SUPPORT_SYSTEM_EVENT = (byte) 0xA1;
    /**
     * Param-Tag for CSPAuditSupport (3/3):
     * 'resourceEvents': Event types of category "resource event". (OPTIONAL)
     */
    byte TAG_AUDIT_SUPPORT_RESOURCE_EVENT = (byte) 0xA2;

    /**
     * Param-Tag for CSPAuditSettings (1/3):
     * 'auditMode': Select audit mode to specify the handling of a full audit event queue. (OPTIONAL)
     */
    byte TAG_AUDIT_SETTINGS_AUDIT_MODE = (byte) 0x80;
    /**
     * Param-Tag for CSPAuditSettings (2/3):
     * 'systemEvents': The system events that shall be audited. (OPTIONAL)
     */
    byte TAG_AUDIT_SETTINGS_SYSTEM_EVENT = (byte) 0xA1;
    /**
     * Param-Tag for CSPAuditSettings (3/3):
     * 'auditSigningKey': The key that shall be used to sign the audit log messages. (OPTIONAL)
     */
    byte TAG_AUDIT_SETTINGS_RESOURCE_ID = (byte) 0x82;

    /**
     * Param-Tag for CSPLogMessage (1/5):
     * 'eventType': Event type; value can be taken from CSPSystemEvent or CSPResourceEvent.
     */
    byte TAG_LOG_MESSAGE_INTEGER = (byte) 0x80;
    /**
     * Param-Tag for CSPLogMessage (2/5):
     * 'fieldsAddedAsPrefix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_LOG_MESSAGE_FIELD = (byte) 0xA1;
    /**
     * Param-Tag for CSPLogMessage (3/5):
     * 'eventData': Event-specific log data. (OPTIONAL)
     */
    byte TAG_LOG_MESSAGE_EVENT_DATA = (byte) 0xA2;
    /**
     * Param-Tag for CSPLogMessage (4/5):
     * 'inputData': Additional input data provided by the Client through audit.dequeueEvent. (OPTIONAL)
     */
    byte TAG_LOG_MESSAGE_OCTET_STRING = (byte) 0x83;
    /**
     * Param-Tag for CSPLogMessage (5/5):
     * 'fieldsAddedAsSuffix': Additional Fields to be included; configured by the CSP Admin. (OPTIONAL)
     */
    byte TAG_LOG_MESSAGE_FIELD_B = (byte) 0xA4;

    /**
     * Param-Tag for CSPEventDataUpdateCSP (1/4):
     * 'oldCSPELFVersion': The cspELFVersion of the CSP ELF of the before the SW update.
     */
    byte TAG_EVENT_DATA_UPDATE_ELF_VERSION = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataUpdateCSP (2/4):
     * 'newCSPELFVersion': The cspELFVersion of the CSP ELF after the SW update.
     */
    byte TAG_EVENT_DATA_UPDATE_ELF_VERSION_B = (byte) 0x81;
    /**
     * Param-Tag for CSPEventDataUpdateCSP (3/4):
     * 'cspProtocolVersion': The version of the CSP Protocol before the SW update.
     */
    byte TAG_EVENT_DATA_UPDATE_PROTOCOL_VERSION = (byte) 0x82;
    /**
     * Param-Tag for CSPEventDataUpdateCSP (4/4):
     * 'newProtocolVersion': The cspProtocolVersion of the CSP Protocol after the SW update.
     */
    byte TAG_EVENT_DATA_UPDATE_PROTOCOL_VERSION_B = (byte) 0x83;

    /**
     * Param-Tag for CSPEventDataUpdateConfig (1/3):
     * 'configName': Custom name or identifier set by the CSP Admin via CSPSetup.
     */
    byte TAG_EVENT_DATA_UPDATE_CONFIG_CONFIG_NAME = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataUpdateConfig (2/3):
     * 'oldConfigVersion': The old configVersion of the CSP Configuration before the update.
     */
    byte TAG_EVENT_DATA_UPDATE_CONFIG_CONFIG_VERSION = (byte) 0x81;
    /**
     * Param-Tag for CSPEventDataUpdateConfig (3/3):
     * 'newConfigVersion': The new configVersion of the CSP Configuration after the update.
     */
    byte TAG_EVENT_DATA_UPDATE_CONFIG_CONFIG_VERSION_B = (byte) 0x82;

    /**
     * Param-Tag for CSPEventDataSetTime (1/2):
     * 'oldReferenceTime': The old referenceTime as it was before the update.
     */
    byte TAG_EVENT_DATA_SET_TIME_TIMESTAMP = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataSetTime (2/2):
     * 'newReferenceTime': The new referenceTime after the update.
     */
    byte TAG_EVENT_DATA_SET_TIME_TIMESTAMP_B = (byte) 0x81;

    /**
     * Param-Tag for CSPEventDataGeneralError (1/2):
     * 'reason': Contains the reason of the exception that occurred.
     */
    byte TAG_EVENT_DATA_GENERAL_ERROR_OCTET_STRING = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataGeneralError (2/2):
     * 'resourceId': A resource ID involved to the error (if available). (OPTIONAL)
     */
    byte TAG_EVENT_DATA_GENERAL_ERROR_RESOURCE_ID = (byte) 0x81;

    /**
     * Param-Tag for CSPEventDataResource (1/1):
     * 'resourceId': The identifier of the resource that triggered this event.
     */
    byte TAG_EVENT_DATA_RESOURCE_RESOURCE_ID = (byte) 0x80;

    /**
     * Param-Tag for CSPEventDataKeyDerivation (1/2):
     * 'sourceResourceId': The source resource for key derivation.
     */
    byte TAG_EVENT_DATA_KEY_DERIVATION_RESOURCE_ID = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataKeyDerivation (2/2):
     * 'destResourceId': The target resource where the result is stored.
     */
    byte TAG_EVENT_DATA_KEY_DERIVATION_RESOURCE_ID_B = (byte) 0x81;

    /**
     * Param-Tag for CSPEventDataKeyAgreement (1/3):
     * 'privateKeyId': The local or remote private key.
     */
    byte TAG_EVENT_DATA_KEY_AGREEMENT_RESOURCE_ID = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataKeyAgreement (2/3):
     * 'publicKeyId': The local or remote public key.
     */
    byte TAG_EVENT_DATA_KEY_AGREEMENT_RESOURCE_ID_B = (byte) 0x81;
    /**
     * Param-Tag for CSPEventDataKeyAgreement (3/3):
     * 'sharedSecretId': The resource ID of the destination shared secret.
     */
    byte TAG_EVENT_DATA_KEY_AGREEMENT_RESOURCE_ID_C = (byte) 0x82;

    /**
     * Param-Tag for CSPEventDataPasswordFailure (1/2):
     * 'resourceId': The identifier of the resource that triggered this event.
     */
    byte TAG_EVENT_DATA_PASSWORD_FAILURE_RESOURCE_ID = (byte) 0x80;
    /**
     * Param-Tag for CSPEventDataPasswordFailure (2/2):
     * 'tryCounter': The remaining try counter value.
     */
    byte TAG_EVENT_DATA_PASSWORD_FAILURE_INTEGER = (byte) 0x81;

    /**
     * Param-Tag for CSPFieldSupport (1/3):
     * 'fieldModes': CSP handling modes of how to handle signature fields. (OPTIONAL)
     */
    byte TAG_FIELD_SUPPORT_FIELD_MODE = (byte) 0xA0;
    /**
     * Param-Tag for CSPFieldSupport (2/3):
     * 'fieldTypes': Signature fields to be added to log messages and attestation data. (OPTIONAL)
     */
    byte TAG_FIELD_SUPPORT_FIELD_TYPE = (byte) 0xA1;
    /**
     * Param-Tag for CSPFieldSupport (3/3):
     * 'fieldSources': Available data sources for fields. (OPTIONAL)
     */
    byte TAG_FIELD_SUPPORT_FIELD_SOURCE = (byte) 0xA2;

    /**
     * Param-Tag for CSPFieldSettings (1/1):
     * 'fieldMode': Select the mode for handling unsupported fields. (OPTIONAL)
     */
    byte TAG_FIELD_SETTINGS_FIELD_MODE = (byte) 0x80;

    /**
     * Param-Tag for CSPField (1/2):
     * 'field': Type of the data field.
     */
    byte TAG_FIELD_FIELD_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPField (2/2):
     * 'source': Source from which the data is taken for the field.
     */
    byte TAG_FIELD_SOURCE = (byte) 0xA1;

    /**
     * Param-Tag for CSPFieldValue (1/3):
     * 'field': Type of the data field.
     */
    byte TAG_FIELD_VALUE_FIELD_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPFieldValue (2/3):
     * 'resourceId': The resource used as the data source. (OPTIONAL)
     */
    byte TAG_FIELD_VALUE_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPFieldValue (3/3):
     * 'fieldValue': The value of the field.
     */
    byte TAG_FIELD_VALUE_OCTET_STRING = (byte) 0x82;

    /**
     * Param-Tag for CSPPolicySupport (1/2):
     * 'policyModes': Policy operation modes to specify the handling of unsupported policies. (OPTIONAL)
     */
    byte TAG_POLICY_SUPPORT_POLICY_MODE = (byte) 0xA0;
    /**
     * Param-Tag for CSPPolicySupport (2/2):
     * 'policyTypes': Policy types, e.g., require an authenticated password to allow cipher. (OPTIONAL)
     */
    byte TAG_POLICY_SUPPORT_POLICY_TYPE = (byte) 0xA1;

    /**
     * Param-Tag for CSPPolicySettings (1/1):
     * 'policyMode': Select policy mode to specify the handling of unavailable counter types.
     */
    byte TAG_POLICY_SETTINGS_POLICY_MODE = (byte) 0x80;

    /**
     * Param-Tag for CSPPolicy (1/3):
     * 'policyType': The additional condition that needs to be checked.
     */
    byte TAG_POLICY_POLICY_TYPE = (byte) 0x80;
    /**
     * Param-Tag for CSPPolicy (2/3):
     * 'constrainingResourceId': The associated resource that is evaluated for the policy.
     */
    byte TAG_POLICY_RESOURCE_ID = (byte) 0x81;
    /**
     * Param-Tag for CSPPolicy (3/3):
     * 'additionalData': Policy specific data, e.g., required TA access rights. (OPTIONAL)
     */
    byte TAG_POLICY_OCTET_STRING = (byte) 0x82;

}
